package PAR::StrippedPARL::Dynamic;
use 5.008001;
use strict;
use warnings;
our $VERSION = '0.958';

use base 'PAR::StrippedPARL::Base';

our $Data_Pos = tell DATA;

=head1 NAME

PAR::StrippedPARL::Dynamic - Data package containing a dynamic PARL

=head1 SYNOPSIS

  # For details, see PAR::StrippedPARL::Base.
  PAR::StrippedPARL::Dynamic->write_parl($file) or die "Some error...";

=head1 DESCRIPTION

This class is internal to PAR. Do not use it outside of PAR.

This class is basically just a container for a dynamic binary PAR loader
which doesn't include the PAR code like the F<parl> or F<parl.exe>
you are used to. If you're really curious, I'll tell you it is
just a copy of the F<myldr/par> (or F<myldr/par.exe>) file.

The data is appended during the C<make> phase of the PAR build process,
but only if applicable: If you perl is static, you won't get the dynamic
loader.

If the binary data isn't appended during the build process, the class
methods will return the empty list.

=head1 CLASS METHODS

Inherits the methods from L<PAR::StrippedPARL::Base>.

=cut

sub _data_pos {
    my $class = shift;
    return $Data_Pos;
}

=head1 AUTHORS

Steffen Mueller E<lt>smueller@cpan.orgE<gt>,
Audrey Tang E<lt>cpan@audreyt.orgE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright 2006-2009 by Steffen Mueller E<lt>smueller@cpan.orgE<gt>.

This program is free software; you can redistribute it and/or 
modify it under the same terms as Perl itself.

See F<LICENSE>.

=cut

$^V eq 5.36.0 
    or die sprintf("Perl (%s) version (%vd) doesn't match the version (5.36.0) ".
                   "that PAR::Packer was built with; please rebuild PAR::Packer", 
                   $^X, $^V);

1;

__DATA__
M?T5,1@(!`0````````````,`/@`!````4"(```````!``````````#"Q````
M`````````$``.``-`$``&0`8``8````$````0`````````!``````````$``
M````````V`(```````#8`@````````@``````````P````0````8`P``````
M`!@#````````&`,````````<`````````!P``````````0`````````!````
M!````````````````````````````````````.`9````````X!D`````````
M$`````````$````%`````"``````````(``````````@````````@3L`````
M``"!.P`````````0`````````0````0`````8`````````!@`````````&``
M``````!82````````%A(`````````!`````````!````!@````"L````````
M`+P`````````O````````"@$````````4`0`````````$`````````(````&
M````$*P````````0O````````!"\````````T`$```````#0`0````````@`
M````````!`````0````X`P```````#@#````````.`,```````!0````````
M`%``````````"``````````$````!````(@#````````B`,```````"(`P``
M`````$0`````````1``````````$`````````%/E=&0$````.`,````````X
M`P```````#@#````````4`````````!0``````````@`````````4.5T9`0`
M``!@H0```````&"A````````8*$```````#D`````````.0`````````!```
M``````!1Y71D!@``````````````````````````````````````````````
M```````````0`````````%+E=&0$`````*P`````````O`````````"\````
M``````0`````````!`````````$`````````+VQI8C8T+VQD+6QI;G5X+7@X
M-BTV-"YS;RXR```````$````0`````4```!'3E4``@``P`0````#````````
M``*``,`$`````0`````````!``'`!`````D``````````@`!P`0````!````
M``````0````4`````P```$=.50#Q-.BX?^!CQCG%VS+SLWQQHM]Y$`0````0
M`````0```$=.50``````!`````0``````````````"L```!#````!`````@`
M```@$!``!4`$A"@"``2`A@"$@@D```D@!`B(@!!!N@`""$,`````````````
M`$0``````````````$4``````````````$8`````````1P````````!)````
M``````````!*````2P````````!,````30```$\`````````4````%$```!2
M``````````````````````````````!3````5````%4```!6````5P``````
M````````60````````!:``````````````")!W#3:QJ>4*/@^TGC1\8!9J_,
M9D-%U>R[XY)\LP&+;V_%WQ\5C"7,+L6;MFL)0]8A_^0.^Z%L8,/E/RP-.I<+
MS]Y'+=EQ6!Q_J9R;X:<""D+ZUX=K?YI\,V+;[=1DU'RM2^/`````````````
M````````````````````C0(``!(`````````````````````````]`$``!(`
M````````````````````````C````!$`````````````````````````=`(`
M`!(`````````````````````````2P$``!(`````````````````````````
MSP$``!(`````````````````````````,`(``!(`````````````````````
M`````0```"``````````````````````````R`(``!(`````````````````
M````````9P```!(`````````````````````````LP```!(`````````````
M````````````E````!(`````````````````````````;0(``!(`````````
M````````````````OP(``!(`````````````````````````Y`$``!(`````
M````````````````````WP```!(`````````````````````````[P```!(`
M````````````````````````/0$``!(`````````````````````````<0$`
M`!(`````````````````````````B@```!$`````````````````````````
M8@,``!(`````````````````````````$````"``````````````````````
M````I0(``!(`````````````````````````D@(``!(`````````````````
M````````R@```!(`````````````````````````+````"``````````````
M````````````G0```!(`````````````````````````N````!(`````````
M````````````````EP(``!(`````````````````````````6````"(`````
M````````````````````]0```!8`````````````````````````"`$``!(`
M````````````````````````0P(``!(`````````````````````````(P$`
M`!(`````````````````````````L`(``!(`````````````````````````
MFP$``!(`````````````````````````W0$``!(`````````````````````
M````J@$``!(`````````````````````````4@$``!(`````````````````
M````````-`$``!(`````````````````````````80$``!(`````````````
M````````````?P$``!(`````````````````````````?P(``!(`````````
M````````````````MP$``!(`````````````````````````A@$``!(`````
M````````````````````%0(``!(`````````````````````````>0```!(`
M````````````````````````E`$``!(`````````````````````````C0$`
M`!(`````````````````````````G````!(`````````````````````````
MHP$``!(```````````````````````````(``!(`````````````````````
M````80(``!(`````````````````````````JP```!(`````````````````
M````````Y@```!(`````````````````````````T0```!(`````````````
M````````````R`$``!$`````````````````````````5`(``!$`````````
M````````````````I````!(`````````````````````````:0$``!(`````
M````````````````````&`$``!(`````````````````````````(0(``!(`
M````````````````````````1@```!(`````````````````````````>`$`
M`!(`````````````````````````P````!(`````````````````````````
ML0$``!(`````````````````````````\P,``!$`%0`@P`````````@`````
M````1@,``!(`#``060```````$L"````````_0,``!(`#``@1@````````4%
M````````\P(``!(`#`"@1````````"@`````````.@,``!(`#`#01```````
M`$(!````````S0,``!``%0`HP```````````````````NP,``!``%@!0P```
M````````````````%@,``!(`#``P2P```````&H`````````:P,``!(`#``P
M5@```````-T`````````L@,``!(`#``05P```````$H`````````X@(``!(`
M#`!@0@````````H`````````A@,``!``%0``P```````````````````Y@,`
M`!(`#`!P0@```````"4"````````U`,``!(`#`#02P```````!`!````````
MG@,``!(`#`!000```````"H`````````B`,``"``%0``P```````````````
M````P`,``!(`#`#@3`````````,'````````I@,``!``%@`HP```````````
M````````4`,``!(`#`"@2P```````",`````````)`,``!(`#`"`00``````
M`-@`````````DP,``!(`#`!@5P```````*<!````````4P```!(`#``@(```
M`````"("````````C`,``!(`#`!0(@```````"8```````````,``!(`#`#P
M4P```````#,"````````=P,``!$`#@``8`````````0``````````%]?9VUO
M;E]S=&%R=%]?`%])5$U?9&5R96=I<W1E<E1-0VQO;F5486)L90!?251-7W)E
M9VES=&5R5$U#;&]N951A8FQE`%]?;&EB8U]S=&%R=%]M86EN`%]?8WAA7V9I
M;F%L:7IE`%]?<F5G:7-T97)?871F;W)K`%]?<W1A8VM?8VAK7V9A:6P`7U]E
M;G9I<F]N`'-T<FYC;7``;'-T870V-`!A8V-E<W,`;'-E96LV-`!R96%D`&]P
M96YD:7(`<F5A9&1I<C8T`'-T<FQE;@!?7W-P<FEN=&9?8VAK`'5N;&EN:P!C
M;&]S961I<@!R;61I<@!03%]C=7)R96YT7V-O;G1E>'0`8F]O=%]$>6YA3&]A
M9&5R`%!E<FQ?;F5W6%,`4&5R;%]N97=84U]F;&%G<P!R96%D;&EN:P!097)L
M7W-V7W-E='!V`&UE;6-H<@!097)L7W-V7W-E='!V;@!M96UM;W9E`')E86QL
M;V,`9V5T<&ED`&UE;6-P>0!S=')C:'(`<W1R9'5P`'-T<G1O:P!S=')C;7``
M<W1R<F-H<@!G971U:60`<W1R<W1R`&UK9&ER`%]?97)R;F]?;&]C871I;VX`
M<W1D97)R`%]?9G!R:6YT9E]C:&L`;W!E;C8T`%!E<FQ?9W9?9F5T8VAP=@!0
M97)L7V=E=%]S=@!097)L7V-R;V%K7VYO8V]N=&5X=`!097)L7VUG7W-E=`!0
M97)L7W-Y<U]I;FET,P!097)L7V%T9F]R:U]U;FQO8VL`4&5R;%]A=&9O<FM?
M;&]C:P!03%]D;U]U;F1U;7``4&5R;%]S869E<WES;6%L;&]C`'!E<FQ?<&%R
M<V4`<&5R;%]D97-T<G5C=`!P97)L7V9R964`4&5R;%]S>7-?=&5R;0!P97)L
M7V%L;&]C`'!E<FQ?8V]N<W1R=6-T`'!E<FQ?<G5N`&5X:70`;&EB<&5R;"YS
M;P!L:6)C+G-O+C8`<&%R7V-U<G)E;G1?97AE8P!P87)?8F%S96YA;64`6%-?
M26YT97)N86QS7U!!4E]"3T]4`'!A<E]E;G9?8VQE86X`<&%R7V-U<G)E;G1?
M97AE8U]P<F]C`'!A<E]D:7)N86UE`'-H85]F:6YA;`!G971?=7-E<FYA;65?
M9G)O;5]G971P=W5I9`!P87)?8VQE86YU<`!?24]?<W1D:6Y?=7-E9`!?7V1A
M=&%?<W1A<G0`<VAA7W5P9&%T90!X<U]I;FET`%]?8G-S7W-T87)T`'-H85]I
M;FET`%]E;F0`<&%R7VUK=&UP9&ER`%]E9&%T80!P87)?<V5T=7!?;&EB<&%T
M:`!P87)?9FEN9'!R;V<`;7E?<&%R7W!L`'!A<E]I;FET7V5N=@!'3$E"0U\R
M+C$T`$=,24)#7S(N,S0`1TQ)0D-?,BXT`$=,24)#7S(N,S,`1TQ)0D-?,BXS
M+C(`1TQ)0D-?,BXS+C0`1TQ)0D-?,BXR+C4`+W5S<B]L:6(O<&5R;#4O-2XS
M-B]C;W)E7W!E<FPO0T]210````$``0`"``$``@`#``$``0`"``0``@`"``(`
M`0`!``(``@`!``(``@`"``$``0`"``(``0`%``(``0`"``$``0`!``$``0`"
M``(``@`!``(``@`"``$``@`"``$`!@`"``(`!0`"``$``0`"``(``P`"``$`
M`@`"``$``0`'``@``@`"``$``0`!``$``0`!``$``0`!``$``0`!``$``0`!
M``$``0`!``$``0`!``$``0`!``$```````$`!P#8`@``$`````````"4D98&
M```(``H$```0````M)&6!@``!P`5!```$````!1I:0T```8`(`0``!````"S
MD98&```%`"H$```0````<AEI"0``!``U!```$````'09:0D```,`000``!``
M``!U&FD)```"`$T$`````````+P````````(`````````$`C````````"+P`
M```````(`````````/`B````````",`````````(``````````C`````````
M(,`````````(`````````-AB````````^+T````````&`````0``````````
M`````+X````````&`````@``````````````"+X````````&`````P``````
M````````$+X````````&````!```````````````&+X````````&````!0``
M````````````(+X````````&````!@``````````````*+X````````&````
M!P``````````````,+X````````&````"```````````````.+X````````&
M````"0``````````````0+X````````&````"@``````````````2+X`````
M```&````"P``````````````4+X````````&````#```````````````6+X`
M```````&````#0``````````````8+X````````&````#@``````````````
M:+X````````&````#P``````````````<+X````````&````$```````````
M````>+X````````&````$0``````````````@+X````````&````$@``````
M````````B+X````````&````$P``````````````D+X````````&````%0``
M````````````F+X````````&````%@``````````````H+X````````&````
M%P``````````````J+X````````&````&```````````````L+X````````&
M````&0``````````````N+X````````&````&@``````````````P+X`````
M```&````&P``````````````R+X````````&````'```````````````T+X`
M```````&````'0``````````````V+X````````&````'@``````````````
MX+X````````2````'P``````````````Z+X````````&````(```````````
M````\+X````````&````(0``````````````^+X````````&````(@``````
M`````````+\````````&````(P``````````````"+\````````&````)```
M````````````$+\````````&````)0``````````````&+\````````&````
M)@``````````````(+\````````&````)P``````````````*+\````````&
M````*```````````````,+\````````&````*0``````````````.+\`````
M```&````*@``````````````0+\````````&````*P``````````````2+\`
M```````&````+```````````````4+\````````&````+0``````````````
M6+\````````&````+@``````````````8+\````````&````+P``````````
M````:+\````````&````,```````````````<+\````````&````,0``````
M````````>+\````````&````,@``````````````@+\````````&````,P``
M````````````B+\````````&````-```````````````D+\````````&````
M-0``````````````F+\````````&````-@``````````````H+\````````&
M````-P``````````````J+\````````&````.```````````````L+\`````
M```&````.0``````````````N+\````````&````.@``````````````P+\`
M```````&````.P``````````````R+\````````&````/```````````````
MT+\````````&````/0``````````````V+\````````&````/@``````````
M````X+\````````&````/P``````````````Z+\````````&````0```````
M````````\+\````````&````00``````````````^+\````````&````0@``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``#S#Q[Z2(/L"$B+!2&>``!(A<!T`O_02(/$",,``````/,/'OI54TB#[#B)
M?"0<2(U\)!Q(B70D$$B-="002(E4)`A(C50D"&1(BP0E*````$B)1"0H,<#_
M%7N?``!(BS7$G0``2(L]A9X``$B)\F?H[#H``$B+!3V?``"`.``/A"(!``!(
MBP55G@``9$B+`("(*@0```.+1"0<C7@$C5@#2&/_2,'G`_\5XYX``$B+3"00
M1(M$)!Q(B<9(B06'GP``2(L!2(D&2(T%]4```$B)1@A(C05'GP``2(L`2(E&
M$$B-!=]```!(B48808/X`0^.,@$``$B#P0A!@\`#N`0```!F#Q]$``!(BSE(
M8]"#P`%(@\$(2(D\UD0YP'7J2)A(B?&)VDB+/0R?``!(QP3&`````$4QP$B-
M-8(<``#_%<R<``")PX7`#X2*````2(UL)"1(BSW>G@``_Q7@G0``,<!(B>Y(
MC3TW/P``Z$\8``!(A<!T=DB+/;N>``#_%76<``#_%4>=``!(BT0D*&1(*P0E
M*`````^%GP```$B#Q#B)V%M=P_\5])P``$B)!86>``!(B<=(A<!T=O\5/YT`
M`$B+!1B=``!D2(L0QH+7"0```.FS_O__2(L]69X``/\5>YP``(G#Z6+___](
MBSU-G@``2(7_=`MGZ#(T``#I<____TB-/4X^``!(B>[HKA<``$B)!2>>``!(
MB<=(A<`/A%'____KT;@$````Z>W^__^_`0```/\5_)L``/\5'IT``&8N#Q^$
M```````/'T``\P\>^C'M28G17DB)XDB#Y/!05$4QP#')2(T]L?W___\5:YT`
M`/1F+@\?A```````2(T]H9T``$B-!9J=``!(.?AT%4B+!?Z;``!(A<!T"?_@
M#Q^``````,,/'X``````2(T]<9T``$B--6J=``!(*?Y(B?!(P>X_2,'X`T@!
MQDC1_G042(L%W9L``$B%P'0(_^!F#Q]$``###Q^``````/,/'OJ`/2V=````
M=3-52(,]TIL```!(B>5T#4B+/?:<``#_%<";``#H8____\8%!)T```%=PV8N
M#Q^$``````##9F8N#Q^$```````/'T``\P\>^NEG____#Q^``````$%72(G^
M3(U'.$%6055!5%532('LF`(``&1(BP0E*````$B)A"2(`@``,<!(B>),C8PD
M@````$B)UP\?@`````!!BP!-BQ!(@\<028/`"`_(B<!,B=%(B4?P3(G02,'I
M($C!Z"A)P>HX)0#_``!,"=!)B<I(P>$(2<'B&('A``#_`$6)TDP)T$@)R$B)
M1_A,.<]UK68/;T0D$&8/;UPD($B-1"1H2('":`(``&8/;U0D,&8/;RT7?0``
M#Q^``````/,/;PAF#V_B9@]O4-A(@\`09@_O0(AF#^_*9@_OP68/;\AF#W/0
M'V8/<_$!9@_KP68/V\4/*4`(9@]OPV8/;]Q(.=!UNTR+#DR+7A!(BWX@2(M>
M&$R)R$R)RDB+;@A(BTPD"$C!ZAM(P>`%2`G0`P0D2(V,"YEY@EJ-E#B9>8):
M3(G82#'82"'H2#'8C3P"2(GJ2(GH2,'H`DC!XAY)B?I("<),B=A)P>H;08G0
M3#'`3"'(3#'82`'(2(GY2,'A!4P)T4R+5"001(TD"$R)R$R)R4C!Z0)(P>`>
M3XV4$YEY@EI-B>5("<A)P>T;2#'"B<%((?I,,<),`=)-B>))P>(%30GJ3(ML
M)!A!`=)(B?I(P>\"2,'B'D6)TD^-A"B9>8):2`GZ38G52#'0B==,(>!)P>T;
M2#'(3`'`38G02<'@!4T)Z$R+;"0@00'`3(G@2<'L`DC!X!Y%B<!*C8PIF7F"
M6DP)X$V)Q4@QPDG![1M!B<1,(=)(,?I(`<I,B<%(P>$%3`GI3(ML)"@!T4R)
MTDG!Z@)(P>(>B<E*C;POF7F"6DP)TDF)S4@QT$G![1M!B=),(<!,,>!(`?A(
MB<](P><%3`GO3(ML)#`!QTR)P$G!Z`)(P>`>B?]/C:0LF7F"6DP)P$F)_4@Q
MPDG![1M!B<!((<I,,=),`>))B?Q)P>0%30GL3(ML)#A!`=1(B<I(P>D"2,'B
M'D6)Y$^-E"J9>8):2`G*38GE2#'02<'M&XG12"'X3#'`3`'038GB2<'B!4T)
MZDR+;"1`00'"2(GX2,'O`DC!X!Y%B=)/C80HF7F"6D@)^$V)U4@QPDG![1N)
MQTPAXD@QRDP!PDV)T$G!X`5-">A,BVPD2$$!T$R)XDG![`)(P>(>18G`2HV,
M*9EY@EI,">)-B<5(,=!)P>T;08G43"'02#'X2`'(3(G!2,'A!4P)Z4R+;"10
M`<%,B=!)P>H"2,'@'HG)2HV\+YEY@EI,"=!)B<U(,<))P>T;08G"3"'"3#'B
M2`'Z2(G/2,'G!4P)[TR+;"18`==,B<))P>@"2,'B'HG_3XVD+)EY@EI,"<))
MB?U(,=!)P>T;08G02"'(3#'03`'@28G\2<'D!4T)[$R+;"1@00'$2(G(2,'@
M'DC!Z0)%B>1/C90JF7F"6D@)R$V)Y4@QPDG![1N)P4@A^DPQPDP!TDV)XDG!
MX@5-">I,BVPD:$$!TDB)^DC![P)(P>(>18G23XV$*)EY@EI("?I-B=5(,=!)
MP>T;B==,(>!(,<A,`<!-B=!)P>`%30GH3(ML)'!!`<!,B>!)P>P"2,'@'D6)
MP$J-C"F9>8):3`G@38G%2#'"2<'M&T&)Q$PATD@Q^D@!RDR)P4C!X05,">E,
MBVPD>`'13(G22,'B'DG!Z@*)R4J-O"^9>8):3`G228G-2#'02<'M&T&)TDPA
MP$PQX$@!^$B)STC!YP5,">],BZPD@`````''3(G`2<'H`DC!X!Z)_T^-I"R9
M>8):3`G`28G]2#'"2<'M&T&)P$@ARDPQTDP!XDF)_$G!Y`5-">Q&C2PB2(G*
M2,'I`DR+I"2(````2,'B'D@)RD^-E"*9>8):38GL2#'02<'L&XG12"'X3#'`
M3`'038GJ2<'B!4T)XDR+I"20````00'"2(GX2,'@'DC![P)%B=)/C80@F7F"
M6D@)^$V)U$@QPDG![!N)QTPAZD@QRDP!PDV)T$G!X`5-">!%B<!,`<)-B>A)
MP>T"2<'@'D&)U$T)Z$R+K"28````3#'`3"'02HV,*9EY@EI-B>5(,?A)P>T;
M2`'(3(GA2,'A!4P)Z8G)2`'(3(G12<'J`DC!X1Y!B<5,"=%-B<)%B<!),<I$
M,=),BY0DH````$J-O!>AZ]EN38GJ2`'73(GJ2<'J&TC!X@5,"=*)TD@!UTR)
MXDC!XAY)P>P"08GZ3`.$)*@```!,">))B<R)R4@#C"2P````23'41#'@38VD
M`*'KV6Y,B=!-B=!)P>@;2,'@!4P)P(G`20'$3(GH2<'M`DC!X!Y%B>!,">A)
MB=6)TD@#E"2X````23'%1#'O3(VL.:'KV6Y,B<%,B<=(P>\;2,'A!4@)^8G)
M20'-3(G12<'J`DC!X1Y$B>],"=%)B<*)P$DQRD4QXDZ-I!*AZ]EN2(GZ28GZ
M2<'J&TC!X@5,"=*)TDD!U$R)PDG!Z`)(P>(>18GB3`G"28G(2`.$),````")
MR4DQT$@#C"3(````13'H3HVL`*'KV6Y,B=!-B=!)P>@;2,'@!4P)P(G`20'%
M2(GX2,'O`DC!X!Y%B>A("?A(B=>)TD@#E"30````2#''1#'G3(VD.:'KV6Y,
MB<%,B<=(P>\;2,'A!4@)^8G)20',3(G12<'J`DC!X1Y$B>=,"=%)B<*)P$@#
MA"38````23'*13'J3HVL$J'KV6Y(B?I)B?I)P>H;2,'B!4P)THG220'53(G"
M2<'H`DC!XAY%B>I,"<))B<B)R4DQT$@#C"3@````13'@3HVD`*'KV6Y,B=!-
MB=!)P>@;2,'@!4P)P(G`20'$2(GX2,'O`DC!X!Y%B>!("?A(B=>)TD@#E"3H
M````2#''1#'O3(VL.:'KV6Y,B<%,B<=(P>\;2,'A!4@)^8G)20'-3(G12<'J
M`DC!X1Y$B>],"=%)B<*)P$@#A"3P````23'*13'B3HVD$J'KV6Y(B?I)B?I)
MP>H;2,'B!4P)THG220'43(G"2<'H`DC!XAY%B>),"<))B<B)R4DQT$4QZ$Z-
MK`"AZ]EN3(G038G02,'@!4G!Z!M(`XPD^````$P)P(G`20'%2(GX2,'O`DC!
MX!Y%B>A("?A(B=>)TD@#E"0``0``2#''1#'G3(VD.:'KV6Y,B<%,B<=(P>\;
M2,'A!4@)^8G)20',3(G12<'J`DC!X1Y$B>=,"=%)B<*)P$@#A"0(`0``23'*
M13'J3HVL$J'KV6Y(B?I)B?I)P>H;2,'B!4P)THG220'53(G"2<'H`DC!XAY%
MB>I,"<))B<B)R4DQT$4QX$Z-I`"AZ]EN3(G038G02<'H&TC!X`5,"<!(`XPD
M$`$``(G`20'$2(GX2,'O`DC!X!Y%B>!("?A(B=>)TD@#E"08`0``2#''1#'O
M3(VL.:'KV6Y,B<%,B<=(P>\;2,'A!4@)^8G)20'-3(G12<'J`DC!X1Y$B>],
M"=%)B<*)P$@#A"0@`0``23'*13'B3HVD$J'KV6Y(B?I)B?I)P>H;2,'B!4P)
MTHG220'43(G"2<'H`DC!XAY%B>),"<))B<B)R4DQT$4QZ$Z-K`"AZ]EN3(G0
M38G02<'H&TC!X`5,"<")P$D!Q4B)^$C!X!Y(P>\"18GH2`.,)"@!``!("?A(
MB=>)TD@#E"0P`0``2#''1#'G38G$2(V,.:'KV6Y,B<=)P>P;2,'G!4P)YTV)
MU$G!Z@))P>0>B?]-"=1)B<)(`?F)P$TQXHG/2`.$)#@!``!%,>I)B?U.C902
MH>O9;DB)^DG![1M(P>(%3`GJ00'23(G"2<'H`DC!XAY%B=),"<)-B>!%B>1)
M,=!)B=9!B=5$,<%-B=!(C8P(H>O9;DR)T$G!Z!M(P>`%3`G`1(T$`4B)^4C!
M[P*XW+P;CTC!X1Y("?E)"<Z)ST@A^DTAUDD)UDB+E"1``0``2`'"3`'B38G$
M3`'R38G&2<'D!4G![AM-"?1!`=1,B=))P>H"2,'B'D6)Y$P)TD@)T4F)UD&)
MTDDA_DPAP4P)\4R+M"1(`0``20'&30'U38GF3`'I38GE2<'N&TG!Y05-"?5)
MB=9!`<U,B<%)P>@"2,'A'D6)[4P)P4&)R$D)SDTAYDPAPDP)\DR+M"10`0``
M20'&3`'W38GN2`'Z3(GO2<'N&TC!YP5,"?<!UTR)XDG![`)(P>(>B?],">)(
M"=%)B=9!B=1-(<9,(>E,"?%,B[0D6`$``$D!QDT!\DF)_DP!T4F)^DG![AM)
MP>(%30GR28G600'*3(GI2<'M`DC!X1Y%B=),">E!B<U)"<Y)(?Y,(>I,"?),
MB[0D8`$``$D!QDT!\$V)UDP!PDV)T$G!X`5)P>X;30GP00'02(GZ2,'O`DC!
MXAY%B<!("?I("=%)B=:)UTTA[DPAT4P)\4R+M"1H`0``20'&30'T38G&3`'A
M38G$2<'N&TG!Y`5-"?1)B=9!`<Q,B=%)P>H"2,'A'D6)Y$P)T4&)RDD)SDTA
MQDPATDP)\DR+M"1P`0``20'&30'U38GF3`'J38GE2<'N&TG!Y05-"?5!`=5,
MB<)(P>(>2<'H`D6)[4P)PD@)T4F)UD&)T$TAUDPAX4P)\4R+M"1X`0``20'&
M3`'W38GN2`'Y3(GO2<'N&TC!YP5,"?=)B=8!STR)X4G![`)(P>$>B?],">%!
MB<Q)"<Y-(>Y,(>),"?),B[0D@`$``$D!QDT!\DF)_DP!TDF)^DG![AM)P>(%
M30GR00'23(GJ2<'M`DC!XAY%B=),">I("=%)B=9!B=5((?E-(>9,"?%,B[0D
MB`$``$D!QDT!\$V)UDP!P4V)T$G![AM)P>`%30GP28G600'(2(GY2,'O`DC!
MX1Y%B<!("?F)STD)SDTAUD@A^DP)\DR+M"20`0``20'&30'T38G&3`'B38G$
M2<'N&TG!Y`5-"?1!`=1,B=))P>H"2,'B'D6)Y$P)TD@)T4F)UD&)TDDA_DPA
MP4P)\4R+M"28`0``20'&30'U38GF3`'I38GE2<'N&TG!Y05-"?5)B=9!`<U,
MB<%)P>@"2,'A'D6)[4P)P4&)R$D)SDTAYDPAPDP)\DR+M"2@`0``20'&3`'W
M38GN2`'Z3(GO2<'N&TC!YP5,"?<!UTR)XDG![`)(P>(>B?],">)("=%)B=9!
MB=1-(<9,(>E,"?%,B[0DJ`$``$D!QDT!\DF)_DP!T4F)^DG![AM)P>(%30GR
M28G600'*3(GI2<'M`DC!X1Y%B=),">E!B<U)"<Y)(?Y,(>I,"?),B[0DL`$`
M`$D!QDT!\$V)UDP!PDV)T$G![AM)P>`%30GP00'02(GZ2,'O`DC!XAY%B<!(
M"?I("=%)B=:)UTTA[DPAT4P)\4R+M"2X`0``20'&30'T38G&3`'A38G$2<'N
M&TG!Y`5-"?1)B=9!`<Q,B=%)P>H"2,'A'D6)Y$P)T4D)SD&)RDTAQDPATDP)
M\DR+M"3``0``20'&30'U38GF3`'J38GE2<'N&TG!Y05-"?5!`=5,B<))P>@"
M2,'B'D6)[4P)PD@)T4F)T$&)UTTAT$PAX4P)P4R+A"3(`0``20'`3`''38GH
M2`'Y3(GO2<'H&TC!YP5,"<=$C00Y3(GG2<'L`DB)T4C!YQY,">=!B?Q("?E,
M(>E,(>)("<I(BXPDT`$``$@!P4P!T4V)PD@#A"38`0``2`'*3(G!2<'J&TC!
MX05,"=&)R4@!RDR)Z4G![0)(P>$>08G23`GI2`G/28G-08G.3"''32'E20G]
M2HT\.$R)T$R+O"3X`0``3`'O38G52,'@!4G![1M,">B)P$@!QTR)P$G!Z`)(
MP>`>08G]20G`N-;!8LI,,<$QT4B+E"3@`0``2`'"3`'B38GL2`'*3(GI2<'L
M&TC!X05,">%-B=2)R4G!Y!Y(`<I)P>H"20''30GB38G$B=%%B<!-,=1$,>=,
MBZ0DZ`$``$D!Q$T!]$F)SDP!YTF)S$G![AM)P>0%30GT38GN2<'M`DG!YAY%
MB>1-"?5,B[0D\`$``$P!YT&)_$D!QDT!\$V)UDTQ[D0Q\DV)YDD!T$R)XDG!
M[AM(P>(%3`GRB=))`=!(B<I(P>D"2,'B'D6)QD@)RD2)T4V)ZDDQTDP!^4R+
MO"0``@``1#'738GR2`'/3(GQ2,'A!4G!ZAM)`<=,"=&)R4@!STR)X4G![`)(
MP>$>08GZ20G,1(GI28G5B=)-,>5,`?E,B[PD$`(``$4QZ$V)U4D!R$R)T4G!
M[1M)`<=(P>$%3`GIB<E)`<A,B?%)P>X"2,'A'D6)Q4P)\4R+M"0(`@``20'&
M3`'R38GF23'.1#'W38GN2`'73(GJ2<'N&TC!X@5,"?*)TD@!UTR)TDG!Z@)(
MP>(>08G^20G21(GB28G,B<E,`?I-,=1,B[PD(`(``$4QX$V)]$D!T$R)\DG!
M[!M)`<=(P>(%3`GBB=))`=!,B>I)P>T"2,'B'D6)Q$P)ZDR+K"08`@``20'%
M3`'I38G523'51#'O38GE2`'/3(GA2<'M&TC!X05,">F)R4@!STR)\4G![@)(
MP>$>08G]20G.1(G128G2B=)-,?),`?E,B[PD,`(``$4QT$V)ZDD!R$R)Z4G!
MZAM(P>$%3`G1B<E)`<A,B>%(P>$>2<'L`D6)PDD!QTP)X4R+I"0H`@``20'$
M3`'B38GT23',1#'G38G42`'73(G22<'L&TC!X@5,">*)TD@!UTR)ZDG![0)(
MP>(>08G\20G51(GR28G.B<E-,>Y,`?I,B[PD0`(``$4Q\$V)YDD!T$R)XDG!
M[AM(P>(%3`GRB=))`=!,B=))P>H"2,'B'D6)QDP)TDR+E"0X`@``20'"3`'1
M38GJ23'21#'738GR2`'/3(GQ2,'A!4G!ZAM)`<=,"=&)R4@!STR)X4G![`)(
MP>$>08GZ20G,1(GI28G5B=)-,>5,`?E,B[PD8`(``$4QZ$V)U4D!R$R)T4G!
M[1M(P>$%3`GIB<E)`<A,B?%)P>X"2,'A'D6)Q4P)\4R+M"1(`@``20'&3`'R
M38GF18GD23'.1#'W38GN2`'73(GJ2<'N&TC!X@5,"?*)TD@!UTR)TDG!Z@)(
MP>(>08G^20G22(N4)%`"``!(`<))`=1(B<J)R4PQTDD!QT0QPDV)\$D!U$R)
M\DG!Z!M(P>(%3`G"B=))`=1,B>I)P>T"2,'B'D6)X$P)ZDR+K"18`@``20'%
M3`'I38G523'51#'O38G%2`'/3(G!2<'M&TC!X05,">F)R4@!STR)\4G![@)(
MP>$>08G]20G.1(G128G2B=)-,?),`?E,B[PD<`(``$4QXDV)[$P!T4V)ZDG!
M[!M)P>(%30GB38G$18G22<'D'DP!T4G!Z`))`<=-">!,BZ0D:`(``$&)RDD!
MQ$@#A"1X`@``3`'B38GT3`'(33'$1#'G38G42`'73(G22<'L&TC!X@5,">)-
MB>Q)P>T"2<'D'HG230GE18GT38G&2`'733'NB?I-`?Q%B<!$,?%)B=9,`<!-
MB>A,`>%)B=1)P>X;2<'D!4T)]$0!X4V)U$G!Z@))P>0>B<E-">)-,=!$,<=)
MB<A(`?A(B<](P><%2<'H&P'I00':3`G'1`-N($B)3@@!^$R)5AA(B09(B=!(
MP>H"2,'@'DR);B!("=!$`=A(B4802(N$)(@"``!D2"L$)2@```!U$DB!Q)@"
M``!;74%<05U!7D%?P_\5I84```\?1```05=!5D%505154TB#[`A(A?\/A+$`
M``!(BP4JA```3(LP387V#X2>````#[8'28G_28GUA,!T!#P]=55%,>1)BQY(
MA=MT,4UCY$R)]0\?0`!,B>),B?Y(B=__%3&$``"%P'4'0H`\(SUT1DB+70A(
M@\4(2(7;==E(@\0(2(G86UU!7$%=05Y!7\,/'X``````28G\00^V1"0!28/$
M`83`=`0\/77N12G\ZY1F#Q]$``!,*?5*C5PC`4C!_0-!B6T`Z[5F#Q]$```Q
MV^NK#Q]``%-(B?M(@>R@````9$B+!"4H````2(F$))@````QP$B)YO\5P80`
M`(7`=36+5"08@>(`\```@?H`0```=`B!^@"@``!U';X"````2(G?_Q7=A```
MA<`/E,`/ML#K!0\?`#'`2(N4))@```!D2"L4)2@```!U"4B!Q*````!;P_\5
M3(0``&9F+@\?A```````D$%455-,C9PD``#__TB![``0``!(@PPD`$PYW'7O
M2(/L$+H"````,?9D2(L$)2@```!(B80D"``!`#'`08G\2(GC_Q4QA```2(UH
M_TB)ZDC!^C](P>HP2(U$%0`/M\!(*=!(*<4/B)H```!F#Q]$```QTDB)[D2)
MY_\5^H,``+H(``$`2(G>1(GG_Q69@@``2)A(@_@'=EE(C40#^$@YV')/2(T5
M2(0``.L/9@\?1```2(/H`4@YV'(W2(L*2#D(=>](*=A(`>A(BY0D"``!`&1(
M*Q0E*````'4S2('$$``!`%M=05S#9BX/'X0``````$B![0```0!(@?T``/__
M#X5L____2,?`_____^NZ_Q4M@P``9F8N#Q^$``````!FD$%505154TB![*@`
M``!D2(L$)2@```!(B80DF````#'`2(7_=`B`/P!(B?MU*TB+A"28````9$@K
M!"4H````#X4S`0``2('$J````%M=05Q!7<-F#Q]$``#_%2J"``!(B<5(A<!T
MQTB)[_\508,``$B%P`^$N````(!X$RY,C6`3=0Y!@'PD`0!TW&8/'T0``(!X
M$RX/A+8```!(B=__%<V!``!,B>=)B<7_%<&!``!!C7P%`DAC__\56X$``$V)
MX4F)V+X!````28G%2(G',<!(Q\+_____2(T-YB(``/\5A((``$R)[TB)YO\5
MD($``$R)[X/X_W00BT0D&"4`\```/0!```!T:/\5(H$``$R)[_\548$``$B)
M[_\5D((``$B%P`^%3____P\?@`````!(B>__%2>"``!(B=__%?:```#IYO[_
M_V8/'X0``````$&`?"0!+@^%/O___T&`?"0"``^$_O[__^DM____#Q\`Z(O^
M___KE_\5HX$```\?`/,/'OI32(L=%($``$B-#35C``!(C34P(@``2(L5!X$`
M`&1(BSO_%>6!``!,C06N(P``9$B+.T4QR4B-%?`5``!,B<%(C34<(@``6_\E
MYX```&9F+@\?A```````#Q]``$%505154TB![``0``!(@PPD`$B#[!BZ_P\`
M`&1(BP0E*````$B)A"0($```,<!)B>1(B?M(B?5(C3W=(0``3(GF_Q7!@```
MA<!^$HG!@^@!2&/0@#P4`'5'A<!U.TB+!5R```!(B>I(B=YD2(LX_Q7L?P``
M2(N$)`@0``!D2"L$)2@```!U3DB!Q!@0``!;74%<05W##Q\`B<%F#Q]$``!,
M8^F^+P```$R)YTR)ZO\51'\``$B%P'2D2(L%`(```$R)Z4R)XDB)WF1(BSC_
M%2V```#KG_\598````\?1```05=!5D%505152(GU4TB)^TB#["AD2(L$)2@`
M``!(B40D&#'`,<"`/CT/E,!(`<5(B>__%7A_``!(C70D%$B)WTF)Q#'`Z';Z
M__](A<`/A`T!``!)B<5(B<?_%5%_``!,.>`/@]@```!(8TPD%$R+-91^``!,
MC3S-``````^V`X3`#X2A`0``/#T/A)D!``!(B=AF#Q]$```/ME`!2(/``832
M=`6`^CUU[T@IV$B838LN2HU\(`+_%9Q^``!-`?U)B44`2(7`=%%)BP9(C4L!
M2HL4.`^V`X@"A,!T(3P]=0SK&V8/'T0``(3`=!$/M@%(@\(!2(/!`8@"/#UU
MZ\8"/3'`9@\?1```#[9,!0"(3`(!2(/``83)=>](BT0D&&1(*P0E*`````^%
M#P$``$B#Q"A;74%<05U!7D%?PP\?0``QP&8/'T0```^V5`4`08A4!0!(@\`!
MA-)U[NN]#Q]``$R+-:%]``!-BP9)@S@`#X2[````3(G`13'M9@\?1```2(/`
M"$2)ZD&#Q0%(@S@`=>^-<@-(8_9(P>8#BP6/?P``A<!U6TB)]TR)1"0(QP5Y
M?P```0```/\5FWT``$B)QTB%P`^$4/___TECS4B+="0(3(T\S0````!,B?K_
M%4Y^``!)B09(B<=!C44!1(EL)!1(F$C'!,<`````Z7S^__],B<?_%;]^``!)
MB09(B<=(A<`/A`'___])8\U,C3S-`````.O##Q\`,<#I?_[__[X0````13'M
MZ5______%1Y^``!F9BX/'X0```````\?`/,/'OI(BP6%?0``2(L5AGT``$B-
M#9]?``!(C36:'@``9$B+./\E5GX``&8/'T0``/,/'OI54TB![``0``!(@PPD
M`$B![``0``!(@PPD`$B#["AD2(L$)2@```!(B80D&"```#'`2(V<)!`0``!(
MB>7_%<)\``"Z`1```$B)W[X!````08G`3(T-:1X``#'`2(T-9!X``/\5O'T`
M`+H`$```2(GN2(G?_Q4K?0``A<!X4XUX`4B)PTAC__\52'P``$B%P'0_2&/;
M2(GN2(G'2(G:_Q7!?0``Q@08`$B)P4B+A"08(```9$@K!"4H````=0U(@<0H
M(```2(G(6UW#_Q4,?0``,<GKU@\?A```````\P\>^ND7____D&8/'T0``/,/
M'OI!5T%6055!5%532('L`!```$B##"0`2('LN````&1(BP0E*````$B)A"2H
M$```,<!)B?Q(B?-(C3VG'0``2(UT)`SH!??__[XO````3(GG2(G%_Q5L?```
M2(7`=#\QP$R)YDB-/80=``#H'OS__TR)X$B+E"2H$```9$@K%"4H````#X63
M`0``2('$N!```%M=05Q!74%>05_#9I!(B=],C2U4'0``3(TU.AX``/\5*7P`
M`$R)[DB)Q_\5/7P``$B)PTB%P'26@#L`#X3G````#Q]``$B%[7042(G>2(GO
M_Q4/?```A<`/A*H```!(B=__%49[``!(C50#_TF)QT@YTW(5ZR0/'X``````
MQ@(`2(/J`4@YTW0%@#HO=.](B=__%19[``!)B<=,B>?_%0I[``!)C40'`4@]
M_P\```^'&O___TR-O"2@````3(GQ28G8,<!(@^P(N@`0``"^`0```$R)_T%4
M3(T-CQP``/\5P7L``$R)_TB-="0@_Q7+>@``6EF%P'40BT0D*"4`\```/0"`
M``!T54R)[C'__Q5:>P``2(G#2(7`#X2O_O__@#L`#X4=____2(7M=`:`?0`N
M=!I!OP$```!(C1T3'```Z57___\/'X0``````(!]`0!TM>O>#Q^$``````"^
M`0```$R)__\54GL``(7`=9E,B?Y(C3WE&P``Z'_Z__],B?__%<9Z``#I5O[_
M__\5RWH``&9F+@\?A```````\P\>^E.^+P```$B)^_\557H``$B-4`%(A<!(
M#T7:2(G?6_\EB'H```\?A```````\P\>^E532('L`!```$B##"0`2(/L&&1(
MBP0E*````$B)A"0($```,<!(A?\/A,X```"`/P!(B?L/A,(```#_%9QY``!(
MC5`!2('Z`!````^'XP```$B)Y4B)[X/Z"'(.B=%(B=[!Z0/S2*5(B?,QR?;"
M!'0)BPN)#[D$````]L("=`Y$#[<$"V9$B00/2(/!`H/B`70'#[84"X@4#TB-
M1`7_2#G%<A7K&`\?@`````#&``!(@^@!2#GH=`6`."]T[[XO````2(GO_Q5I
M>0``2(7`="Q(.<5R5TB)[_\5GGD``$B+E"0($```9$@K%"4H````=4=(@<08
M$```6UW#D$B+A"0($```9$@K!"4H````=2E(@<08$```2(T]91H``%M=_R57
M>0``#Q^``````,8``.ND#Q\`,<#KIO\53GD``&9F+@\?A```````#Q\`\P\>
M^D%7059!54%454B-+3X:``!32(/L&&1(BP0E*````$B)1"0(,<!(C5PD!&:0
M,<!(B=Y(B>_H8_/__TB%P'0^2(L%GW<``$AC5"0$2(L`2(T$T$B+4`A(B1!(
MA=)TSP\?@`````!(BU`02(/`"$B)$$B%TG7PZ[9F#Q]$``!(C2W4&0``9@\?
MA```````,<!(B=Y(B>_H`_/__TB%P'0^2(L%/W<``$AC5"0$2(L`2(T$T$B+
M4`A(B1!(A=)TSP\?@`````!(BU`02(/`"$B)$$B%TG7PZ[9F#Q]$``!(C2U\
M&0``9@\?A```````,<!(B=Y(B>_HH_+__TB%P'0^2(L%WW8``$AC5"0$2(L`
M2(T$T$B+4`A(B1!(A=)TSP\?@`````!(BU`02(/`"$B)$$B%TG7PZ[9F#Q]$
M``!(C2TE&0``9@\?A```````,<!(B=Y(B>_H0_+__TB%P'0^2(L%?W8``$AC
M5"0$2(L`2(T$T$B+4`A(B1!(A=)TSP\?@`````!(BU`02(/`"$B)$$B%TG7P
MZ[9F#Q]$``!(C2W,&```9@\?A```````,<!(B=Y(B>_HX_'__TB%P'0^2(L%
M'W8``$AC5"0$2(L`2(T$T$B+4`A(B1!(A=)TSP\?@`````!(BU`02(/`"$B)
M$$B%TG7PZ[9F#Q]$``!,C25\&```9@\?A```````,<!(B=Y,B>?H@_'__TB%
MP'0^2(L%OW4``$AC5"0$2(L`2(T$T$B+4`A(B1!(A=)TSP\?@`````!(BU`0
M2(/`"$B)$$B%TG7PZ[9F#Q]$``!,C271%P``9@\?A```````,<!(B=Y,B>?H
M(_'__TB%P'0^2(L%7W4``$AC5"0$2(L`2(T$T$B+4`A(B1!(A=)TSP\?@```
M``!(BU`02(/`"$B)$$B%TG7PZ[9F#Q]$``!,C37(%P``9@\?A```````,<!(
MB=Y,B??HP_#__TB%P'0^2(L%_W0``$AC5"0$2(L`2(T$T$B+4`A(B1!(A=)T
MSP\?@`````!(BU`02(/`"$B)$$B%TG7PZ[9F#Q]$``!,C2UR%P``9@\?A```
M````,<!(B=Y,B>_H8_#__TB%P'0^2(L%GW0``$AC5"0$2(L`2(T$T$B+4`A(
MB1!(A=)TSP\?@`````!(BU`02(/`"$B)$$B%TG7PZ[9F#Q]$``!,C3T<%P``
M9@\?A```````,<!(B=Y,B?_H`_#__TB%P'0^2(L%/W0``$AC5"0$2(L`2(T$
MT$B+4`A(B1!(A=)TSP\?@`````!(BU`02(/`"$B)$$B%TG7PZ[9F#Q]$``!,
MC3U:%@``9@\?A```````,<!(B=Y,B?_HH^___TB%P'0^2(L%WW,``$AC5"0$
M2(L`2(T$T$B+4`A(B1!(A=)TSP\?@`````!(BU`02(/`"$B)$$B%TG7PZ[9F
M#Q]$``!(B=Y(C3UC%@``Z%'O__](A<!T#4B)QDR)[S'`Z'_T__\QP$B)WDB-
M/5$6``#H+N___TB%P'012(G&2(T]3Q8``#'`Z%CT__](B=Y(C3U)%@``,<#H
M!^___TB)QDB%P'0Y3(GG,<#H-?3__TB+1"0(9$@K!"4H````=41(@\082(GO
M2(TU,Q8``#'`6UU!7$%=05Y!7^D&]/__,<!(B=Y(C3T%%@``Z+7N__](A<!T
MNTB)QDR)]S'`Z./S___KK/\5.W0``&9F+@\?A```````\P\>^DB#[!A(C3UP
M%0``9$B+!"4H````2(E$)`@QP$B-="0$Z&?N__](A<!T,@^V$(#Z,`^4P(32
M#Y3""="#\`$/ML!(BU0D"&1(*Q0E*````'402(/$&,,/'X``````,<#KX/\5
MQG,``&8/'T0``/,/'OI(@^P(_Q72<P``B<?_%=IR``!(A<!T`TB+`$B#Q`C#
M9F8N#Q^$``````!FD/,/'OI!54%43(TE/Q4``%5(B?U,B>=32(/L&&1(BP0E
M*````$B)1"0(,<!(C70D!.B[[?__2(7`=`B`.`!(B<-U+DB+1"0(9$@K!"4H
M````#X6T````2(GN2(/$&$R)YS'`6UU!7$%=Z</R__\/'P!(B>Y(B<?_%<QR
M``!(A<!T'TB+1"0(9$@K!"4H````=7E(@\086UU!7$%=PP\?0`!(B>__%3=R
M``!(B=])B<7_%2MR``!)C7P%`O\5R'$``$B#[`A)B>B^`0```%-(Q\+_____
M2(G'28G%3(T-O1,``$B-#:,4```QP/\5Z'(``%A:2(M$)`AD2"L$)2@```!U
M"$R)[NE/_____Q6`<@``\P\>^D%72(T52!0``$B-#?43``!!5F9(#V["2(T5
M!!0``$F)_D%52(T]2A,``$%455-(@>PX`0``9$B+!"4H````2(F$)"@!``!(
MC04E$P``2(UL)!1(QT0D4`````!(QX0DB`````````!(B>Y(QT0D,`````!F
M2`]NR$B-!=<3``!F#VS!9D@/;M!(C07/$P``#RE$)$!F2`]NP69(#V[82(T-
MO1,``&8/;,)(C06W$P``#Q%$)&AF2`]NPF9(#V[@,<!F#VS##Q%$)'AF2`]N
MP68/;,0/*40D(.C_Z___2(7`=`R`.`!(B<,/A98$``#_%:AQ``")Q_\5L'``
M`$B%P`^$!P0``$R+($V%Y`^$^P,``$R)Y_\5LG```$B-?``!_Q5/<```10^V
M!"1)B<=(B<-%A,!T-TR-+303``!)@\0!10^VP$R)_TR)Z4C'PO____^^`0``
M`#'`28/'`O\58G$``$4/M@0D183`==!,C6PD8$B-/902``#K#V:028M]"$F#
MQ0A(A?]T.TB)[C'`Z$GK__])B<1(A<!TX8`X`'3<2(G'Z`3L__^%P'303(GG
M_Q6W<```28G'2(7`=3\/'X``````3(UD)$!-BSPD387_="I!@#\`#X0@`P``
M3(G_Z,CK__^%P`^%$`$``$V+?"0(28/$"$V%_W789I!,B?__%<=O``!(B=])
MB<3_%;MO``!%C:0$!`0``$UCY$R)Y_\53V\``%--B?A,C0U<$0``28G%2(T%
M1!(``+X!````2,?"_____U!(C0TG$@``3(GO,<#_%6MP``!,B>^^P`$``/\5
MK7```%]!6(/X_W43_Q7O;P``1(L(08/Y$0^%U`(``$B-A"20````3(GO2(D$
M)$B)QO\5^F\``(G#A<!T?$B+!25P``!)BPY-B>A(C15X$@``O@$```!(BS@Q
MP/\5>&X``$4QY$B+A"0H`0``9$@K!"4H````#X4;!```2('$.`$``$R)X%M=
M05Q!74%>05_#9@\?A```````3(G_28/$"/\58V\``$F)QTB%P`^$M/[__^GB
M_O__9I"+A"2H````)0#P```]`$````^%;?___T2+O"2L````_Q5;;P``03G'
M#X56____BX0DJ````"7_`0``/<`!```/A3____],B>?_%0IN``!(B>Y(C3W1
M$```28G$,<#H7NG__TB%P`^$70(``$F+/DB)QF?H^?'__TF)QTB%P`^$10(`
M`$R)__\5)&X``$B)PH/X`WX\2)A(B50D"$B--<40``!)C7P'_/\5NVX``(7`
M=1](BU0D"(/Z!`^$X0(``(U"^TB808`\!R\/A-$"``"02(GN2(TMU0\``#'`
M2(GOZ-SH__](A<`/A.,!```/M@"$P`^$V`$``#PP#X30`0``2(GO2(TU$A``
M`#'`Z._M__](C2V($```3(TU;Q```/\58VT``%5(Q\+_____38GH4$R-#3@/
M``"^`0```$R)YTB-#3D0```QP/\566X``%A:ZT@/'T0``/\5ZFT``(,X$75+
M_Q4?;0``@\,!2(/L"$V)Z%5,C0WU#@``3(GQO@$```!32,?"_____TR)YU`Q
MP/\5$6X``$B#Q""^P`$``$R)Y_\53VX``(/X_W2J3(GO_Q7Q;```3(GF2(T]
MEPX``#'`Z#CM__],B>=GZ/_Y___IU?W__V8N#Q^$``````!%,?_I^/S__P\?
MA```````2(U<)"#K#68/'X0``````$B#PPA(BSM(A?\/A)(````QP$B)[NBF
MY___2(7`=.&`.`!TW$B)Q_\5(VT``$F)Q$B%P'3+Z;O[__](BP5O;0``28L.
M38GH2(T5@@\``+X!````2(LX,<#_%<)K``#I1?W__P\?1```2(G'9^A?^?__
M2(N$)"@!``!D2"L$)2@````/A54!``!(@<0X`0``2(G?6UU!7$%=05Y!7_\E
MKFP``+\-````3(TE@`X``/\5I&L``$&X4P```$F)QTB)P^E4^___#Q\`38L^
MZ;/]__\Q]DR)_S'`_Q4S;```08G&A<`/A!C^__^)Q^@QZ/__28G'2(7`#X@%
M_O__,=)(C7#V1(GW_Q6.;```2(UT)!JZ!@```$2)]_\5*VL``(%\)!H`0T%#
M#X75_?__9H%\)!Y(10^%R/W__TF-=\XQTD2)]_\546P``$B+'"2Z*````$2)
M]TB)WO\5[&H``+X!````38GH3(GG2(T%,@X``,:$)+@`````2(T-]`T``$C'
MPO____]03(T-Y`P``#'`4_\5$VP``%E>Z1+^__\/'T``38MV"$V%]@^$(_W_
M_TR)]_\5^FH``$B#^`,/AA#]__])C7P&_$B--:`-``#_%99K``"%P$T/1/[I
M\_S___\5?6L``&9F+@\?A```````9I#S#Q[Z051(C3V6#```55-(@^P02(L=
MUFH``&1(BP0E*````$B)1"0(,<!,C60D!$R)YF1(BRL/MH6P````B(6Q````
M,<#HAN7__TB%P'0)@#@Q#X1P`0``,<!GZ-#Q__]D2(LK2(GON0,```"Z`0``
M`$B--3<-``#_%?II``!(B<5(A<!T*4B+0!!D2(L[2(T5'`T``$B+,/\5\FD`
M`$B+11!(BS#V1@Y`#X51`0``9$B+.[D#````N@$```!(C37R#```_Q6N:0``
M2(G%2(7`="Y,B>9(C3V5"P``,<#H[>3__TB)PDB%P`^$\0```$B+11!D2(L[
M2(LP_Q60:0``9$B+.[H!````2(TUJ`P``/\5^F@``&1(BSM(C16L#```2(G&
M_Q5F:0``9$B+`TR)YDB-/3`+``#&@+$`````,<#HBN3__TB)!0-K``!(B<-(
MA<!T0[[``0``2(G?_Q6E:@``C5`!@_H!=@F#^!$/A9L```!(BT0D"&1(*P0E
M*`````^%I0```$B#Q!!;74%<PP\?@`````!(BSVY:@``9^A+]___2(D%I&H`
M`$B)PTB%P'6A2(T]O0P``#'`_Q75:0``#Q]$``"`>`$`#X22_O__Z8'^__]F
M#Q^$``````!(BP5Q:@``2(LP2(M%$$B+..@ZZ/__Z07___\/'T0``&1(BSO_
M%5YI``#IH/[__XG!2(L%0&H``$B)VDB-/7X,``!(BS`QP/\5:VD``/\5/6D`
M`&9F+@\?A```````9I#S#Q[Z54B)_5-(@^P89$B+!"4H````2(E$)`@QP&?H
M?>[__[XO````2(G#2(G'_Q6D:```2(7`2(U0`4@/1=I(B=__%=AH``!(C70D
M!$B-/2L*``!(B<,QP.@RX___2(7`=!T/MA"$T@^4P(#Z,`^4P@C0=0M(A>UT
M!H!]``!U($B+1"0(9$@K!"4H````=4=(@\086UW#9@\?A```````N@0```!(
MC36&"@``2(G?_Q5K9P``A<!UQTB+1"0(9$@K!"4H````=0Y(@\082(GO6UWI
M.>7___\54V@```\?`/,/'OI(@^P(OX````#_%35G``!F#V\%!4H``$C'0#``
M````#Q$`9@]O!0)*``#'0'@`````#Q%`$&8/;P7_20``#Q%`($B#Q`C#9@\?
M1```\P\>^D%72&/"059)B<9!54%428G\54B-;SA32(GS2(/L"$B+=RA(BU<P
MC0S&2#GQ2(E/*$B#T@!(P>@=2`'02(E',$AC1WB%P`^%Z0```$&#_C\/CB\!
M``!!@^Y`18GW0<'O!D6-;P%)P>4&20'=D/,/;P-,B>=(@\-`#Q%%`/,/;TO0
M#Q%-$/,/;U/@#Q%5(/,/;UOP#Q%=,.A1R___3#GK=<Q!P><&12G^26/&2(/X
M"')<28M5`$B-30A(@^'X28E4)#A)BU0%^$B)5`7X2"G-2`'H22GM2(/@^$B#
M^`AR&$B#X/@QTDF+=!4`2(DT$4B#P@A(.<)R[D6)="1X2(/$"%M=05Q!74%>
M05_#9I"H!'5\2(7`=.%!#[95`$&(5"0XJ`)TTT$/MU0%_F:)5`7^Z\8/'T``
M0;]`````2(U\!0!(B=Y!*<=%.?=%#T_^36/O3(GJ_Q4L9P``08M$)'A$`?A!
MB40D>(/X0'613(GG12G^3`'KZ'3*___ISO[__P\?@`````!)B=WI&____T&+
M50!!B50D.$&+5`7\B50%_.E3____9@\?A```````\P\>^D%63(UV.$%50515
M2(G]4TR+;BA(B?-,BV8P3(GH2,'H`X/@/XU(`4B8QD0&.(!(8\%,`?"#^3@/
MCG\!``"^0````"G.=`\QTHG1@\(!Q@0(`#GR<O-(B=_HW\G__V8/[\`/$4,X
M2<=&,`````!!#Q%&$$$/$48@3(GB00^VQ4R)[TR)[DC!ZAA(P>`(3(GA2,'O
M$$F)T$R)ZDC![A@/MM9`#[;_0`^V]DC!Z1!("=!,B>(/MLE(P>`(2`GX#[;^
M00^VT$C!X`A("?!!#[;T2,'@"$@)\$C!X`A("?A(B=](P>`(2`G(2,'@"$@)
MT$B)0W#H1LG__TB+`TB)WTC!Z!B(10!(BP-(P>@0B$4!2(L#B&4"2(L#B$4#
M2(M#"$C!Z!B(101(BT,(2,'H$(A%!4B+0PB(909(BT,(B$4'2(M#$$C!Z!B(
M10A(BT,02,'H$(A%"4B+0Q"(90I(BT,0B$4+2(M#&$C!Z!B(10Q(BT,82,'H
M$(A%#4B+0QB(90Y(BT,8B$4/2(M#($C!Z!B(11!(BT,@2,'H$(A%$4B+0R"(
M91)(BT,@B$436UU!7$%=05[_)=UC```/'T0``+HX````,?\IRH/Z"')"B=%(
MQP``````2,=$"/@`````2(U("$B#X?A(*<@!PH/B^(/Z"`^"@O[__X/B^#'`
MB<:#P`A(B3PQ.=!R\^EK_O__]L($=2.%T@^$7O[__\8``/;"`@^$4O[__S')
M9HE,$/[I1O[__P\?`,<``````,=$$/P`````Z3#^__\/'T0``/,/'OI(BPV=
M9```_R7/8@``````\P\>^DB#[`A(@\0(PP``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````0`"`"5S+R5S`$1Y;F%,;V%D97(Z.F)O;W1?1'EN84QO861E<@!)
M;G1E<FYA;',Z.E!!4CHZ0D]/5``O<')O8R]S96QF+V5X90`O<')O8R\E:2\E
M<P`N`%!!4E]414U0`%!!4E]04D]'3D%-10`Z`"\`4$523#5,24(`4$523$Q)
M0@!015),-4]05`!015),24\`4$%27TE.251)04Q)6D5$`%!!4E]34$%73D5$
M`%!!4E]#3$5!3@!005)?1$5"54<`4$%27T-!0TA%`%!!4E]'3$]"04Q?1$5"
M54<`4$%27T=,3T)!3%]435!$25(`4$%27U1-4$1)4@!005)?1TQ/0D%,7U1%
M35``4$%27T=,3T)!3%]#3$5!3@`Q`$Q$7TQ)0E)!4EE?4$%42`!365-414T`
M+W1M<`!414U01$E2`%1-4`!54T52`%5315).04U%`"4P,G@`)7,E<R5S)7,`
M<&%R+0!P87)L`"YP87(`)7,E<V-A8VAE+25S)7,`)7,E<W1E;7`M)74E<P`E
M<R5S=&5M<"TE=2TE=25S`!@`<&5R;``P`%!!4CHZ4&%C:V5R.CI615)324].
M`#$N,#4W`"UE`"TM```````````E<SH@8W)E871I;VX@;V8@<')I=F%T92!S
M=6)D:7)E8W1O<GD@)7,@9F%I;&5D("AE<G)N;STE:2D*````````)7,Z('!R
M:79A=&4@<W5B9&ER96-T;W)Y("5S(&ES('5N<V%F92`H<&QE87-E(')E;6]V
M92!I="!A;F0@<F5T<GD@>6]U<B!O<&5R871I;VXI"@```````%5N86)L92!T
M;R!C<F5A=&4@8V%C:&4@9&ER96-T;W)Y```````````E<SH@8W)E871I;VX@
M;V8@<')I=F%T92!C86-H92!S=6)D:7)E8W1O<GD@)7,@9F%I;&5D("AE<G)N
M;STE:2D*``````````!E=F%L("=E>&5C("]U<W(O8FEN+W!E<FP@("U3("0P
M("1[,2LB)$`B?2<*:68@,#L@(R!N;W0@<G5N;FEN9R!U;F1E<B!S;VUE('-H
M96QL"G!A8VMA9V4@7U]P87)?<&P["FUY("@D4$%27TU!1TE#+"`D1DE,15]O
M9F9S971?<VEZ92P@)&-A8VAE7VYA;65?<VEZ92D["D)%1TE.('L*)%!!4E]-
M04=)0R`](")<;E!!4BYP;5QN(CL*)$9)3$5?;V9F<V5T7W-I>F4@/2`T.R`@
M(",@<&%C:R@B3B(I"B1C86-H95]N86UE7W-I>F4@/2`T,#L*)%!+6DE07TU!
M1TE#(#T@(E!+7#`P,UPP,#0B.PI]"G-U8B!F:6YD7W!A<E]M86=I8PI["FUY
M("@D9F@I(#T@0%\["FUY("1C:'5N:U]S:7IE(#T@-C0@*B`Q,#(T.PIM>2`D
M8G5F.PIM>2`D<VEZ92`]("US("1F:#L*;7D@)'!O<R`]("@D<VEZ92TQ*2`M
M("@D<VEZ92TQ*2`E("1C:'5N:U]S:7IE.R`@("`@(",@3D]413H@)'!O<R!I
M<R!A(&UU;'1I<&QE(&]F("1C:'5N:U]S:7IE"G=H:6QE("@D<&]S(#X](#`I
M('L*<V5E:R`D9F@L("1P;W,L(#`["G)E860@)&9H+"`D8G5F+"`D8VAU;FM?
M<VEZ92`K(&QE;F=T:"@D4$%27TU!1TE#*3L*:68@*"AM>2`D:2`](')I;F1E
M>"@D8G5F+"`D4$%27TU!1TE#*2D@/CT@,"D@>PIR971U<FX@)'!O<R`K("1I
M.PI]"B1P;W,@+3T@)&-H=6YK7W-I>F4["GT*<F5T=7)N("TQ.PI]"FUY("@D
M<&%R7W1E;7`L("1P<F]G;F%M92P@0'1M<&9I;&4L("5-;V1U;&5#86-H92D[
M"D5.1"![(&EF("@D14Y6>U!!4E]#3$5!3GTI('L*<F5Q=6ER92!&:6QE.CI4
M96UP.PIR97%U:7)E($9I;&4Z.D)A<V5N86UE.PIR97%U:7)E($9I;&4Z.E-P
M96,["FUY("1T;W!D:7(@/2!&:6QE.CI"87-E;F%M93HZ9&ER;F%M92@D<&%R
M7W1E;7`I.PIO=71S*'%Q6U)E;6]V:6YG(&9I;&5S(&EN("(D<&%R7W1E;7`B
M72D["D9I;&4Z.D9I;F0Z.F9I;F1D97!T:"AS=6(@>R`H("UD("D@/R!R;61I
M<B`Z('5N;&EN:R!]+"`D<&%R7W1E;7`I.PIR;61I<B`D<&%R7W1E;7`["FEF
M("@M9"`D<&%R7W1E;7`@)B8@)%Y/(&YE("=-4U=I;C,R)RD@>PIM>2`D=&UP
M(#T@;F5W($9I;&4Z.E1E;7`H"E1%35!,051%(#T^("=T;7!86%A86"<L"D1)
M4B`]/B!&:6QE.CI"87-E;F%M93HZ9&ER;F%M92@D=&]P9&ER*2P*4U5&1DE8
M(#T^("<N8VUD)RP*54Y,24Y+(#T^(#`L"BD["FUY("1F:6QE;F%M92`]("1T
M;7`M/F9I;&5N86UE.PIP<FEN="`D=&UP(#P\(BXN+B(["G@],3L@=VAI;&4@
M6R!<)'@@+6QT(#$P(%T[(&1O"G)M("UR9B`G)'!A<E]T96UP)PII9B!;(%PA
M("UD("<D<&%R7W1E;7`G(%T[('1H96X*8G)E86L*9FD*<VQE97`@,0IX/6!E
M>'!R(%PD>"`K(#%@"F1O;F4*<FT@)R1F:6QE;F%M92<*+BXN"F-L;W-E("1T
M;7`["F-H;6]D(#`W,#`L("1F:6QE;F%M93L*;7D@)&-M9"`]("(D9FEL96YA
M;64@/B]D978O;G5L;"`R/B8Q("8B.PIS>7-T96TH)&-M9"D["F]U=',H<7%;
M4W!A=VYE9"!B86-K9W)O=6YD('!R;V-E<W,@=&\@<&5R9F]R;2!C;&5A;G5P
M.B`D9FEL96YA;65=*3L*?0I]('T*0D5'24X@>PI);G1E<FYA;',Z.E!!4CHZ
M0D]/5"@I(&EF(&1E9FEN960@)DEN=&5R;F%L<SHZ4$%2.CI"3T]4.PIE=F%L
M('L*7W!A<E]I;FET7V5N=B@I.PIM>2`D<75I970@/2`A)$5.5GM005)?1$5"
M54=].PIM>2`E<WES(#T@*`IP871H7W-E<"`@("`]/B`H)%Y/(#U^("]>35-7
M:6XO(#\@)SLG(#H@)SHG*2P*7V5X92`@("`@("`@/3X@*"1>3R`]?B`O7B@_
M.DU35VEN?$]3,GQC>6=W:6XI+R`_("<N97AE)R`Z("<G*2P*7V1E;&EM("`@
M("`@/3X@*"1>3R`]?B`O7DU35VEN?$]3,B\@/R`G7%PG(#H@)R\G*2P**3L*
M7W-E=%]P<F]G;F%M92@I.PIO=71S*'%Q6UPD<')O9VYA;64@/2`B)'!R;V=N
M86UE(ETI.PI?<V5T7W!A<E]T96UP*"D["F]U=',H<7%;7"1%3E9[4$%27U1%
M35!](#T@(B1%3E9[4$%27U1%35!](ETI.PIM>2`H)'-T87)T7W!O<RP@)'-T
M87)T7V]F7T9)3$5?<V5C=&EO;BD["DU!1TE#.B!["FQO8V%L("1324=[7U]7
M05).7U]](#T@<W5B('M].PIU;FQE<W,@*&]P96X@7T9(+"`G/#IR87<G+"`D
M<')O9VYA;64I('L*;W5T<RAQ<5M#86XG="!R96%D(&9R;VT@9FEL92`B)'!R
M;V=N86UE(ETI.R`@(R!D;VXG="!U<V4@)"$@:&5R92!A<R!I="!R97%U:7)E
M<R!%<G)N;RYP;0IL87-T($U!1TE#.PI]"FUY("1M86=I8U]P;W,@/2!F:6YD
M7W!A<E]M86=I8R@J7T9(*3L*:68@*"1M86=I8U]P;W,@/"`P*2!["F]U=',H
M<7%;0V%N)W0@9FEN9"!M86=I8R!S=')I;F<@(B1005)?34%'24,B(&EN(&9I
M;&4@(B1P<F]G;F%M92)=*3L*;&%S="!-04=)0SL*?0IO=71S*")&;W5N9"!0
M05(@;6%G:6,@870@<&]S:71I;VX@)&UA9VEC7W!O<R(I.PIS965K(%]&2"P@
M)&UA9VEC7W!O<R`M("1&24Q%7V]F9G-E=%]S:7IE("T@;&5N9W1H*")<,$-!
M0TA%(BDL(#`["G)E860@7T9(+"`D8G5F+"!L96YG=&@H(EPP0T%#2$4B*3L*
M:68@*"1B=68@;F4@(EPP0T%#2$4B("8F("1B=68@;F4@(EPP0TQ%04XB*2![
M"F]U=',H(DYO(&-A8VAE(&UA<FME<B!F;W5N9"(I.PIL87-T($U!1TE#.PI]
M"F]U=',H<7%;0V%C:&4@;6%R:V5R("(D8G5F(B!F;W5N9%TI.PIS965K(%]&
M2"P@)&UA9VEC7W!O<R`M("1&24Q%7V]F9G-E=%]S:7IE+"`P.PIR96%D(%]&
M2"P@)&)U9BP@)$9)3$5?;V9F<V5T7W-I>F4["FUY("1O9F9S970@/2!U;G!A
M8VLH(DXB+"`D8G5F*3L*;W5T<R@B3V9F<V5T(&9R;VT@<W1A<G0@;V8@1DE,
M17,@:7,@)&]F9G-E="(I.PIS965K(%]&2"P@)&UA9VEC7W!O<R`M("1&24Q%
M7V]F9G-E=%]S:7IE("T@)&]F9G-E="P@,#L*)'-T87)T7V]F7T9)3$5?<V5C
M=&EO;B`]('1E;&P@7T9(.PIM>2`E<F5Q=6ER95]L:7-T.PIR96%D(%]&2"P@
M)&)U9BP@-#L@("`@("`@("`@("`@("`@("`@("`@("`@("`C(')E860@=&AE
M(&9I<G-T(")&24Q%(@IW:&EL92`H)&)U9B!E<2`B1DE,12(I('L*<F5A9"!?
M1D@L("1B=68L(#0["G)E860@7T9(+"`D8G5F+"!U;G!A8VLH(DXB+"`D8G5F
M*3L*;7D@)&9U;&QN86UE(#T@)&)U9CL*;W5T<RAQ<5M5;G!A8VMI;F<@1DE,
M12`B)&9U;&QN86UE(BXN+ETI.PIM>2`D8W)C(#T@*"`D9G5L;&YA;64@/7X@
M<WQ>*%MA+69<9%U[.'TI+WQ\("D@/R`D,2`Z('5N9&5F.PIM>2`H)&)A<V5N
M86UE+"`D97AT*2`]("@D8G5F(#U^(&U\*#\Z+BHO*3\H+BHI*%PN+BHI?"D[
M"G)E860@7T9(+"`D8G5F+"`T.PIR96%D(%]&2"P@)&)U9BP@=6YP86-K*").
M(BP@)&)U9BD["FEF("AD969I;F5D*"1E>'0I(&%N9"`D97AT("%^("]<+B@_
M.G!M?'!L?&EX?&%L*20O:2D@>PIM>2`D9FEL96YA;64@/2!?<V%V95]A<R@B
M)&-R8R1E>'0B+"`D8G5F+"`P-S4U*3L*)%!!4CHZ2&5A=GDZ.D9U;&Q#86-H
M97LD9G5L;&YA;65](#T@)&9I;&5N86UE.PHD4$%2.CI(96%V>3HZ1G5L;$-A
M8VAE>R1F:6QE;F%M97T@/2`D9G5L;&YA;64["GT*96QS:68@*"`D9G5L;&YA
M;64@/7X@;7Q>+S]S:&QI8B]\(&%N9"!D969I;F5D("1%3E9[4$%27U1%35!]
M("D@>PIM>2`D9FEL96YA;64@/2!?<V%V95]A<R@B)&)A<V5N86UE)&5X="(L
M("1B=68L(#`W-34I.PIO=71S*")32$Q)0CH@)&9I;&5N86UE7&XB*3L*?0IE
M;'-E('L*)$UO9'5L94-A8VAE>R1F=6QL;F%M97T@/2!["F)U9B`]/B`D8G5F
M+`IC<F,@/3X@)&-R8RP*;F%M92`]/B`D9G5L;&YA;64L"GT["B1R97%U:7)E
M7VQI<W1[)&9U;&QN86UE?2LK.PI]"G)E860@7T9(+"`D8G5F+"`T.PI]"FQO
M8V%L($!)3D,@/2`H<W5B('L*;7D@*"1S96QF+"`D;6]D=6QE*2`]($!?.PIR
M971U<FX@:68@<F5F("1M;V1U;&4@;W(@(21M;V1U;&4["FUY("1I;F9O(#T@
M)$UO9'5L94-A8VAE>R1M;V1U;&5].PIR971U<FX@=6YL97-S("1I;F9O.PID
M96QE=&4@)')E<75I<F5?;&ES='LD;6]D=6QE?3L*)$E.0WLD;6]D=6QE?2`]
M("(O;&]A9&5R+R1I;F9O+R1M;V1U;&4B.PII9B`H)$5.5GM005)?0TQ%04Y]
M(&%N9"!D969I;F5D*"9)3SHZ1FEL93HZ;F5W*2D@>PIM>2`D9F@@/2!)3SHZ
M1FEL92T^;F5W7W1M<&9I;&4@;W(@9&EE(")#86XG="!C<F5A=&4@=&5M<"!F
M:6QE.B`D(2(["B1F:"T^8FEN;6]D92@I.PHD9F@M/G!R:6YT*"1I;F9O+3Y[
M8G5F?2D["B1F:"T^<V5E:R@P+"`P*3L*<F5T=7)N("1F:#L*?0IE;'-E('L*
M;7D@)&9I;&5N86UE(#T@7W-A=F5?87,H(B1I;F9O+3Y[8W)C?2YP;2(L("1I
M;F9O+3Y[8G5F?2D["B1I;F9O+3Y[9FEL97T@/2`D9FEL96YA;64["F]P96X@
M;7D@)&9H+"`G/#IR87<G+"`D9FEL96YA;64@;W(@9&EE('%Q6T-A;B=T(')E
M860@(B1F:6QE;F%M92(Z("0A73L*<F5T=7)N("1F:#L*?0ID:64@(D)O;W1S
M=')A<'!I;F<@9F%I;&5D.B!C86XG="!F:6YD(&UO9'5L92`D;6]D=6QE(2([
M"GTL($!)3D,I.PIR97%U:7)E(%A33&]A9&5R.PIR97%U:7)E(%!!4CHZ2&5A
M=GD["G)E<75I<F4@0V%R<#HZ2&5A=GD["G)E<75I<F4@17AP;W)T97(Z.DAE
M879Y.PI005(Z.DAE879Y.CI?:6YI=%]D>6YA;&]A9&5R*"D["G)E<75I<F4@
M24\Z.D9I;&4["G=H:6QE("AM>2`D9FEL96YA;64@/2`H<V]R="!K97ES("5R
M97%U:7)E7VQI<W0I6S!=*2!["G5N;&5S<R`H)$E.0WLD9FEL96YA;65](&]R
M("1F:6QE;F%M92`]?B`O0E-$4$%.+RD@>PII9B`H)&9I;&5N86UE(#U^("]<
M+G!M8S\D+VDI('L*<F5Q=6ER92`D9FEL96YA;64["GT*96QS92!["F1O("1F
M:6QE;F%M92!U;FQE<W,@)&9I;&5N86UE(#U^("]S:71E8W5S=&]M:7IE7"YP
M;"0O.PI]"GT*9&5L971E("1R97%U:7)E7VQI<W1[)&9I;&5N86UE?3L*?0II
M9B`H)&)U9B!N92`D4$M:25!?34%'24,I('L*;W5T<RAQ<5M.;R!Z:7`@9F]U
M;F0@869T97(@1DE,12!S96-T:6]N(&EN(&9I;&4@(B1P<F]G;F%M92)=*3L*
M;&%S="!-04=)0R`["GT*)'-T87)T7W!O<R`]("AT96QL(%]&2"D@+2`T.R`@
M("`@("`@("`@("`@("`C('-T87)T(&]F('II<`I]"FUY($!P87)?87)G<SL*
M;7D@*"1O=70L("1B=6YD;&4L("1L;V=F:"P@)&-A8VAE7VYA;64I.PID96QE
M=&4@)$5.5GM005)?05!07U)%55-%?3L@(R!S86YI=&EZ92`H4D554T4@;6%Y
M(&)E(&$@<V5C=7)I='D@<')O8FQE;2D*:68@*"$D<W1A<G1?<&]S(&]R("@D
M05)'5ELP72!E<2`G+2UP87(M;W!T:6]N<R<@)B8@<VAI9G0I*2!["FUY("5D
M:7-T7V-M9"`]('%W*`IP("`@8FQI8E]T;U]P87(*:2`@(&EN<W1A;&Q?<&%R
M"G4@("!U;FEN<W1A;&Q?<&%R"G,@("!S:6=N7W!A<@IV("`@=F5R:69Y7W!A
M<@HI.PII9B`H0$%21U8@86YD("1!4D=66S!=(&5Q("<M+7)E=7-E)RD@>PIS
M:&EF="!`05)'5CL*)$5.5GM005)?05!07U)%55-%?2`]('-H:69T($!!4D=6
M.PI]"F5L<V4@>R`C(&YO<FUA;"!P87)L(&)E:&%V:6]U<@IM>2!`861D7W1O
M7VEN8SL*=VAI;&4@*$!!4D=6*2!["B1!4D=66S!=(#U^("]>+2A;04E-3T),
M8G%P:75S5'9=*2@N*BDO(&]R(&QA<W0["FEF("@D,2!E<2`G22<I('L*<'5S
M:"!`861D7W1O7VEN8RP@)#(["GT*96QS:68@*"0Q(&5Q("=-)RD@>PIE=F%L
M(")U<V4@)#(B.PI]"F5L<VEF("@D,2!E<2`G02<I('L*=6YS:&EF="!`<&%R
M7V%R9W,L("0R.PI]"F5L<VEF("@D,2!E<2`G3R<I('L*)&]U="`]("0R.PI]
M"F5L<VEF("@D,2!E<2`G8B<I('L*)&)U;F1L92`]("=S:71E)SL*?0IE;'-I
M9B`H)#$@97$@)T(G*2!["B1B=6YD;&4@/2`G86QL)SL*?0IE;'-I9B`H)#$@
M97$@)W$G*2!["B1Q=6EE="`](#$["GT*96QS:68@*"0Q(&5Q("=,)RD@>PIO
M<&5N("1L;V=F:"P@(CX^(BP@)#(@;W(@9&EE('%Q6T-A;B=T(&]P96X@;&]G
M(&9I;&4@(B0R(CH@)"%=.PI]"F5L<VEF("@D,2!E<2`G5"<I('L*)&-A8VAE
M7VYA;64@/2`D,CL*?0IS:&EF="A`05)'5BD["FEF("AM>2`D8VUD(#T@)&1I
M<W1?8VUD>R0Q?2D@>PID96QE=&4@)$5.5GLG4$%27U1%35`G?3L*:6YI=%]I
M;F,H*3L*<F5Q=6ER92!005(Z.D1I<W0["B9[(E!!4CHZ1&ES=#HZ)&-M9")]
M*"D@=6YL97-S($!!4D=6.PHF>R)005(Z.D1I<W0Z.B1C;60B?2@D7RD@9F]R
M($!!4D=6.PIE>&ET.PI]"GT*=6YS:&EF="!`24Y#+"!`861D7W1O7VEN8SL*
M?0I]"FEF("@D;W5T*2!["GL*<F5Q=6ER92!)3SHZ1FEL93L*<F5Q=6ER92!!
M<F-H:79E.CI::7`["G)E<75I<F4@1&EG97-T.CI32$$["GT*;7D@)'!A<B`]
M('-H:69T*$!!4D=6*3L*;7D@)'II<#L*:68@*&1E9FEN960@)'!A<BD@>PIO
M<&5N(&UY("1F:"P@)SPZ<F%W)RP@)'!A<B!O<B!D:64@<7%;0V%N)W0@9FEN
M9"!P87(@9FEL92`B)'!A<B(Z("0A73L*8FQE<W,H)&9H+"`G24\Z.D9I;&4G
M*3L*)'II<"`]($%R8VAI=F4Z.EII<"T^;F5W.PHH("1Z:7`M/G)E861&<F]M
M1FEL94AA;F1L92@D9F@L("1P87(I(#T]($%R8VAI=F4Z.EII<#HZ05I?3TLH
M*2`I"F]R(&1I92!Q<5M%<G)O<B!R96%D:6YG('II<"!A<F-H:79E("(D<&%R
M(ET["GT*;7D@)6UE=&%?<&%R(#T@9&\@>PII9B`H)'II<"!A;F0@;7D@)&UE
M=&$@/2`D>FEP+3YC;VYT96YT<R@G345402YY;6PG*2D@>PHD;65T82`]?B!S
M+RXJ7G!A<CHD+R]M<SL*)&UE=&$@/7X@<R]>7%,N*B\O;7,["B1M971A(#U^
M("]>("`H6UXZ72LI.B`H+BLI)"]M9SL*?0I].PII9B`H9&5F:6YE9"`D<&%R
M*2!["F]P96X@;7D@)'!H+"`G/#IR87<G+"`D<&%R(&]R(&1I92!Q<5M#86XG
M="!R96%D('!A<B!F:6QE("(D<&%R(CH@)"%=.PIM>2`D8G5F.PIR96%D("1P
M:"P@)&)U9BP@-#L*9&EE('%Q6R(D<&%R(B!I<R!N;W0@82!P87(@9FEL95T@
M=6YL97-S("1B=68@97$@)%!+6DE07TU!1TE#.PIC;&]S92`D<&@["GT*0W)E
M871E4&%T:"@D;W5T*2`["FUY("1F:"`]($E/.CI&:6QE+3YN97<H"B1O=70L
M"DE/.CI&:6QE.CI/7T-214%4*"D@?"!)3SHZ1FEL93HZ3U]21%=2*"D@?"!)
M3SHZ1FEL93HZ3U]44E5.0R@I+`HP-S<W+`HI(&]R(&1I92!Q<5M#86XG="!C
M<F5A=&4@9FEL92`B)&]U="(Z("0A73L*)&9H+3YB:6YM;V1E*"D["G-E96L@
M7T9(+"`P+"`P.PIM>2`D;&]A9&5R.PII9B`H9&5F:6YE9"`D<W1A<G1?;V9?
M1DE,15]S96-T:6]N*2!["G)E860@7T9(+"`D;&]A9&5R+"`D<W1A<G1?;V9?
M1DE,15]S96-T:6]N.PI](&5L<V4@>PIL;V-A;"`D+R`]('5N9&5F.PHD;&]A
M9&5R(#T@/%]&2#X["GT*:68@*"$D14Y6>U!!4E]615)"051)37T@86YD("1L
M;V%D97(@/7X@+UXH/SHC(7Q<0')E;2DO*2!["G)E<75I<F4@4$%2.CI&:6QT
M97(Z.E!O9%-T<FEP.PI005(Z.D9I;'1E<CHZ4&]D4W1R:7`M/F%P<&QY*%PD
M;&]A9&5R+"`D,"D["GT*)&9H+3YP<FEN="@D;&]A9&5R*0IO<B!D:64@<7%;
M17)R;W(@=W)I=&EN9R!L;V%D97(@=&\@(B1O=70B.B`D(5T["FEF("@D8G5N
M9&QE*2!["G)E<75I<F4@4$%2.CI(96%V>3L*4$%2.CI(96%V>3HZ7VEN:71?
M9'EN86QO861E<B@I.PII;FET7VEN8R@I.PIR97%U:7)E7VUO9'5L97,H*3L*
M;7D@0&EN8R`](&=R97`@>R`A+T)31%!!3B\@?0IG<F5P('L**"1B=6YD;&4@
M;F4@)W-I=&4G*2!O<@HH)%\@;F4@)$-O;F9I9SHZ0V]N9FEG>V%R8VAL:6)E
M>'!](&%N9`HD7R!N92`D0V]N9FEG.CI#;VYF:6=[<')I=FQI8F5X<'TI.PI]
M($!)3D,["G-\+RM\+WQG+"!S?"\D?'P@9F]R96%C:"!`:6YC.PIM>2`E9FEL
M97,["B1F:6QE<WLD7WTK*R!F;W(@0$1Y;F%,;V%D97(Z.F1L7W-H87)E9%]O
M8FIE8W1S+"!V86QU97,@)4E.0SL*;7D@)&QI8E]E>'0@/2`D0V]N9FEG.CI#
M;VYF:6=[;&EB7V5X='T[("`@("`@("`@(R!86%@@;&EB7V5X="!V<R!D;&5X
M="`_"FUY("5W<FET=&5N.PIF;W)E86-H(&UY("1K97D@*'-O<G0@:V5Y<R`E
M9FEL97,I('L*;7D@*"1F:6QE+"`D;F%M92D["FEF("AD969I;F5D*&UY("1F
M8R`]("1005(Z.DAE879Y.CI&=6QL0V%C:&5[)&ME>7TI*2!["B@D9FEL92P@
M)&YA;64I(#T@*"1K97DL("1F8RD["GT*96QS92!["F9O<F5A8V@@;7D@)&1I
M<B`H0&EN8RD@>PII9B`H)&ME>2`]?B!M?%Y<421D:7)<12\H+BHI)'QI*2![
M"B@D9FEL92P@)&YA;64I(#T@*"1K97DL("0Q*3L*;&%S=#L*?0II9B`H)&ME
M>2`]?B!M?%XO;&]A9&5R+UM>+UTK+R@N*BDD?"D@>PII9B`H;7D@)')E9B`]
M("1-;V1U;&5#86-H97LD,7TI('L**"1F:6QE+"`D;F%M92D@/2`H)')E9BP@
M)#$I.PIL87-T.PI]"FEF("@M9B`B)&1I<B\D,2(I('L**"1F:6QE+"`D;F%M
M92D@/2`H(B1D:7(O)#$B+"`D,2D["FQA<W0["GT*?0I]"GT*;F5X="!U;FQE
M<W,@9&5F:6YE9"`D;F%M93L*;F5X="!I9B`D=W)I='1E;GLD;F%M97TK*SL*
M;F5X="!I9B`A<F5F*"1F:6QE*2!A;F0@)&9I;&4@/7X@+UPN7%$D;&EB7V5X
M=%Q%)"]I.PIO=71S*'-P<FEN=&8H<7%;4&%C:VEN9R!&24Q%("(E<R(N+BY=
M+"!R968@)&9I;&4@/R`D9FEL92T^>VYA;65](#H@)&9I;&4I*3L*;7D@)&-O
M;G1E;G0["FEF("AR968H)&9I;&4I*2!["B1C;VYT96YT(#T@)&9I;&4M/GMB
M=69].PI]"F5L<V4@>PIL;V-A;"`D+R`]('5N9&5F.PIO<&5N(&UY("1T:"P@
M)SPZ<F%W)RP@)&9I;&4@;W(@9&EE('%Q6T-A;B=T(')E860@(B1F:6QE(CH@
M)"%=.PHD8V]N=&5N="`](#PD=&@^.PIC;&]S92`D=&@["E!!4CHZ1FEL=&5R
M.CI0;V13=')I<"T^87!P;'DH7"1C;VYT96YT+"`B/&5M8F5D9&5D/B\D;F%M
M92(I"FEF("$D14Y6>U!!4E]615)"051)37T@86YD("1N86UE(#U^("]<+B@_
M.G!M?&EX?&%L*20O:3L*4$%2.CI&:6QT97(Z.E!A=&-H0V]N=&5N="T^;F5W
M+3YA<'!L>2A<)&-O;G1E;G0L("1F:6QE+"`D;F%M92D["GT*)&9H+3YP<FEN
M="@B1DE,12(L"G!A8VLH)TXG+"!L96YG=&@H)&YA;64I("L@.2DL"G-P<FEN
M=&8H(B4P.'@O)7,B+"!!<F-H:79E.CI::7`Z.F-O;7!U=&5#4D,S,B@D8V]N
M=&5N="DL("1N86UE*2P*<&%C:R@G3B<L(&QE;F=T:"@D8V]N=&5N="DI+`HD
M8V]N=&5N="D*;W(@9&EE('%Q6T5R<F]R('=R:71I;F<@96UB961D960@1DE,
M12!T;R`B)&]U="(Z("0A73L*;W5T<RAQ<5M7<FET=&5N(&%S("(D;F%M92)=
M*3L*?0I]"FEF("@D>FEP*2!["B1Z:7`M/G=R:71E5&]&:6QE2&%N9&QE*"1F
M:"D@/3T@07)C:&EV93HZ6FEP.CI!6E]/2PIO<B!D:64@<7%;17)R;W(@=W)I
M=&EN9R!Z:7`@<&%R="!O9B`B)&]U=")=.PI]"FEF("@D;65T85]P87)[8VQE
M86Y]*2!["B1F:"T^<')I;G0H(EPP0TQ%04XB*3L*?0IE;'-E('L*:68@*"%D
M969I;F5D("1C86-H95]N86UE*2!["FUY("1C='@@/2!$:6=E<W0Z.E-(02T^
M;F5W*#$I.PIS965K("1F:"P@,"P@,#L*)&-T>"T^861D9FEL92@D9F@I.PIS
M965K("1F:"P@,"P@,CL*)&-A8VAE7VYA;64@/2`D8W1X+3YH97AD:6=E<W0[
M"GT*)&-A8VAE7VYA;64@/2!S=6)S='(@)&-A8VAE7VYA;64L(#`L("1C86-H
M95]N86UE7W-I>F4["B1C86-H95]N86UE("X](")<,"(@>"`H)&-A8VAE7VYA
M;65?<VEZ92`M(&QE;F=T:"`D8V%C:&5?;F%M92D["B1F:"T^<')I;G0H)&-A
M8VAE7VYA;64L"B)<,$-!0TA%(BD["GT*;7D@)&]F9G-E="`]("1F:"T^=&5L
M;"`M(&QE;F=T:"@D;&]A9&5R*3L*)&9H+3YP<FEN="AP86-K*"=.)RP@)&]F
M9G-E="DL"B1005)?34%'24,I.PHD9F@M/F-L;W-E(&]R(&1I92!Q<5M%<G)O
M<B!W<FET:6YG('1R86EL97(@;V8@(B1O=70B.B`D(5T["F-H;6]D(#`W-34L
M("1O=70["F5X:70["GT*>PIL87-T('5N;&5S<R!D969I;F5D("1S=&%R=%]P
M;W,["E]F:7A?<')O9VYA;64H*3L*<F5Q=6ER92!005(["E!!4CHZ2&5A=GDZ
M.E]I;FET7V1Y;F%L;V%D97(H*3L*>PIR97%U:7)E($9I;&4Z.D9I;F0["G)E
M<75I<F4@07)C:&EV93HZ6FEP.PI]"FUY("1F:"`]($E/.CI&:6QE+3YN97<[
M("`@("`@("`@("`@("`@("`@("`@("`@("`@("`C($%R8VAI=F4Z.EII<"!O
M<&5R871E<R!O;B!A;B!)3SHZ2&%N9&QE"B1F:"T^9F1O<&5N*&9I;&5N;RA?
M1D@I+"`G<B<I(&]R(&1I92!Q<5MF9&]P96XH*2!F86EL960Z("0A73L*07)C
M:&EV93HZ6FEP.CIS971#:'5N:U-I>F4H+7,@7T9(*3L*;7D@)'II<"`]($%R
M8VAI=F4Z.EII<"T^;F5W.PHH)'II<"T^<F5A9$9R;VU&:6QE2&%N9&QE*"1F
M:"P@)'!R;V=N86UE*2`]/2!!<F-H:79E.CI::7`Z.D%:7T]+*"DI"F]R(&1I
M92!Q<5M%<G)O<B!R96%D:6YG('II<"!A<F-H:79E("(D<')O9VYA;64B73L*
M07)C:&EV93HZ6FEP.CIS971#:'5N:U-I>F4H-C0@*B`Q,#(T*3L*<'5S:"!`
M4$%2.CI,:6)#86-H92P@)'II<#L*)%!!4CHZ3&EB0V%C:&5[)'!R;V=N86UE
M?2`]("1Z:7`["F]U=',H(D5X=')A8W1I;F<@>FEP+BXN(BD["FEF("AD969I
M;F5D("1%3E9[4$%27U1%35!]*2![(",@<VAO=6QD(&)E('-E="!A="!T:&ES
M('!O:6YT(0IF;W)E86-H(&UY("1M96UB97(@*"`D>FEP+3YM96UB97)S("D@
M>PIN97AT(&EF("1M96UB97(M/FES1&ER96-T;W)Y.PIM>2`D;65M8F5R7VYA
M;64@/2`D;65M8F5R+3YF:6QE3F%M93L*;F5X="!U;FQE<W,@)&UE;6)E<E]N
M86UE(#U^(&U["EX*+S]S:&QI8B\**#\Z)$-O;F9I9SHZ0V]N9FEG>W9E<G-I
M;VY]+RD_"B@_.B1#;VYF:6<Z.D-O;F9I9WMA<F-H;F%M97TO*3\**%M>+UTK
M*0HD"GUX.PIM>2`D97AT<F%C=%]N86UE(#T@)#$["FUY("1D97-T7VYA;64@
M/2!&:6QE.CI3<&5C+3YC871F:6QE*"1%3E9[4$%27U1%35!]+"`D97AT<F%C
M=%]N86UE*3L*:68@*"UF("1D97-T7VYA;64@)B8@+7,@7R`]/2`D;65M8F5R
M+3YU;F-O;7!R97-S9613:7IE*"DI('L*;W5T<RAQ<5M3:VEP<&EN9R`B)&UE
M;6)E<E]N86UE(B!S:6YC92!I="!A;')E861Y(&5X:7-T<R!A="`B)&1E<W1?
M;F%M92)=*3L*?2!E;'-E('L*;W5T<RAQ<5M%>'1R86-T:6YG("(D;65M8F5R
M7VYA;64B('1O("(D9&5S=%]N86UE(BXN+ETI.PHH)&UE;6)E<BT^97AT<F%C
M=%1O1FEL94YA;65D*"1D97-T7VYA;64I(#T]($%R8VAI=F4Z.EII<#HZ05I?
M3TLH*2D*;W(@9&EE('%Q6T5R<F]R(&5X=')A8W1I;F<@>FEP(&UE;6)E<B!T
M;R`B)&1E<W1?;F%M92)=.PIC:&UO9"@P-34U+"`D9&5S=%]N86UE*2!I9B`D
M7D\@97$@(FAP=7@B.PI]"GT*?0I]"G5N;&5S<R`H)%!!4CHZ3&EB0V%C:&5[
M)'!R;V=N86UE?2D@>PID:64@/#P@(BXB('5N;&5S<R!`05)'5CL*57-A9V4Z
M("0P(%L@+4%L:6(N<&%R(%T@6R`M261I<B!=(%L@+4UM;V1U;&4@72!;('-R
M8RYP87(@72!;('!R;V=R86TN<&P@70HD,"!;("U"?"UB(%T@6RU/;W5T9FEL
M95T@<W)C+G!A<@HN"B1%3E9[4$%27U!23T=.04U%?2`]("1P<F]G;F%M92`]
M("0P(#T@<VAI9G0H0$%21U8I.PI]"G-U8B!#<F5A=&50871H('L*;7D@*"1N
M86UE*2`]($!?.PIR97%U:7)E($9I;&4Z.D)A<V5N86UE.PIM>2`H)&)A<V5N
M86UE+"`D<&%T:"P@)&5X="D@/2!&:6QE.CI"87-E;F%M93HZ9FEL97!A<G-E
M*"1N86UE+"`H)UPN+BHG*2D["G)E<75I<F4@1FEL93HZ4&%T:#L*1FEL93HZ
M4&%T:#HZ;6MP871H*"1P871H*2!U;FQE<W,H+64@)'!A=&@I.R`C(&UK<&%T
M:"!D:65S('=I=&@@97)R;W(*?0IS=6(@<F5Q=6ER95]M;V1U;&5S('L*<F5Q
M=6ER92!L:6(["G)E<75I<F4@1'EN84QO861E<CL*<F5Q=6ER92!I;G1E9V5R
M.PIR97%U:7)E('-T<FEC=#L*<F5Q=6ER92!W87)N:6YG<SL*<F5Q=6ER92!V
M87)S.PIR97%U:7)E($-A<G`["G)E<75I<F4@0V%R<#HZ2&5A=GD["G)E<75I
M<F4@17)R;F\["G)E<75I<F4@17AP;W)T97(Z.DAE879Y.PIR97%U:7)E($5X
M<&]R=&5R.PIR97%U:7)E($9C;G1L.PIR97%U:7)E($9I;&4Z.E1E;7`["G)E
M<75I<F4@1FEL93HZ4W!E8SL*<F5Q=6ER92!84TQO861E<CL*<F5Q=6ER92!#
M;VYF:6<["G)E<75I<F4@24\Z.DAA;F1L93L*<F5Q=6ER92!)3SHZ1FEL93L*
M<F5Q=6ER92!#;VUP<F5S<SHZ6FQI8CL*<F5Q=6ER92!!<F-H:79E.CI::7`[
M"G)E<75I<F4@1&EG97-T.CI32$$["G)E<75I<F4@4$%2.PIR97%U:7)E(%!!
M4CHZ2&5A=GD["G)E<75I<F4@4$%2.CI$:7-T.PIR97%U:7)E(%!!4CHZ1FEL
M=&5R.CI0;V13=')I<#L*<F5Q=6ER92!005(Z.D9I;'1E<CHZ4&%T8VA#;VYT
M96YT.PIR97%U:7)E(&%T=')I8G5T97,["F5V86P@>R!R97%U:7)E($-W9"!]
M.PIE=F%L('L@<F5Q=6ER92!7:6XS,B!].PIE=F%L('L@<F5Q=6ER92!38V%L
M87(Z.E5T:6P@?3L*979A;"![(')E<75I<F4@07)C:&EV93HZ56YZ:7`Z.D)U
M<G-T('T["F5V86P@>R!R97%U:7)E(%1I93HZ2&%S:#HZ3F%M961#87!T=7)E
M('T["F5V86P@>R!R97%U:7)E(%!E<FQ)3SL@<F5Q=6ER92!097)L24\Z.G-C
M86QA<B!].PIE=F%L('L@<F5Q=6ER92!U=&8X('T["GT*<W5B(%]S971?<&%R
M7W1E;7`@>PII9B`H9&5F:6YE9"`D14Y6>U!!4E]414U0?2!A;F0@)$5.5GM0
M05)?5$5-4'T@/7X@+R@N*RDO*2!["B1P87)?=&5M<"`]("0Q.PIR971U<FX[
M"GT*9F]R96%C:"!M>2`D<&%T:"`H"BAM87`@)$5.5GLD7WTL('%W*"!005)?
M5$U01$E2(%1-4$1)4B!414U01$E2(%1%35`@5$U0("DI+`IQ=R@@0SI<7%1%
M35`@+W1M<"`N("D**2!["FYE>'0@=6YL97-S(&1E9FEN960@)'!A=&@@86YD
M("UD("1P871H(&%N9"`M=R`D<&%T:#L*;7D@)'5S97)N86UE.PIM>2`D<'=U
M:60["F5V86P@>R@D<'=U:60I(#T@9V5T<'=U:60H)#XI(&EF(&1E9FEN960@
M)#X[?3L*:68@*"!D969I;F5D*"97:6XS,CHZ3&]G:6Y.86UE*2`I('L*)'5S
M97)N86UE(#T@)E=I;C,R.CI,;V=I;DYA;64["GT*96QS:68@*&1E9FEN960@
M)'!W=6ED*2!["B1U<V5R;F%M92`]("1P=W5I9#L*?0IE;'-E('L*)'5S97)N
M86UE(#T@)$5.5GM54T523D%-17T@?'P@)$5.5GM54T52?2!\?"`G4UE35$5-
M)SL*?0IM>2`D<W1M<&1I<B`]("(D<&%T:"1S>7-[7V1E;&EM?7!A<BTB+G5N
M<&%C:R@B2"HB+"`D=7-E<FYA;64I.PIM:V1I<B`D<W1M<&1I<BP@,#<U-3L*
M;7D@)&-A8VAE7V1I<CL*:68@*"1%3E9[4$%27T-,14%.?2D@>PHD8V%C:&5?
M9&ER(#T@(G1E;7`M)"0B.PI]"F5L<V4@>PIO<&5N(&UY("1F:"P@(CPZ<F%W
M(BP@)'!R;V=N86UE(&]R(&1I92!Q<5M#86XG="!R96%D("(D<')O9VYA;64B
M.B`D(5T["FEF("@H;7D@)&UA9VEC7W!O<R`](&9I;F1?<&%R7VUA9VEC*"1F
M:"DI(#X](#`I('L*<V5E:R`D9F@L("1M86=I8U]P;W,*+2`D1DE,15]O9F9S
M971?<VEZ90HM(&QE;F=T:"@B7#!#04-(12(I+"`P.PIM>2`D8G5F.PIR96%D
M("1F:"P@)&)U9BP@;&5N9W1H*")<,$-!0TA%(BD["FEF("@D8G5F(&5Q(")<
M,$-!0TA%(BD@>PIS965K("1F:"P@)&UA9VEC7W!O<PHM("1&24Q%7V]F9G-E
M=%]S:7IE"BT@;&5N9W1H*")<,$-!0TA%(BD*+2`D8V%C:&5?;F%M95]S:7IE
M+"`P.PIR96%D("1F:"P@)&)U9BP@)&-A8VAE7VYA;65?<VEZ93L*)&)U9B`]
M?B!S+UPP+R]G.PHD8V%C:&5?9&ER(#T@(F-A8VAE+21B=68B.PI]"GT*8VQO
M<V4@)&9H.PI]"FEF("@A)&-A8VAE7V1I<BD@>PHD8V%C:&5?9&ER(#T@(G1E
M;7`M)"0B.PHD14Y6>U!!4E]#3$5!3GT@/2`Q.PI]"B1S=&UP9&ER("X]("(D
M<WES>U]D96QI;7TD8V%C:&5?9&ER(CL*;6MD:7(@)'-T;7!D:7(L(#`W-34[
M"B1%3E9[4$%27U1%35!](#T@)'-T;7!D:7(["FQA<W0["GT*)'!A<E]T96UP
M(#T@)#$@:68@)$5.5GM005)?5$5-4'T@86YD("1%3E9[4$%27U1%35!](#U^
M("\H+BLI+SL*?0IS=6(@7W-A=F5?87,@>PIM>2`H)&YA;64L("1C;VYT96YT
M<RP@)&UO9&4I(#T@0%\["FUY("1F=6QL;F%M92`]("(D<&%R7W1E;7`O)&YA
M;64B.PIU;FQE<W,@*"UE("1F=6QL;F%M92D@>PIM>2`D=&5M<&YA;64@/2`B
M)&9U;&QN86UE+B0D(CL*;7D@)&9H.PHH;W!E;B`D9F@L("<^.G)A=R<L("1T
M96UP;F%M92D*)B8@*'!R:6YT("1F:"`D8V]N=&5N=',I"B8F("AC;&]S92`D
M9F@I"F]R(&1I92!Q<5M%<G)O<B!W<FET:6YG("(D=&5M<&YA;64B.B`D(5T[
M"F-H;6]D("1M;V1E+"`D=&5M<&YA;64@:68@9&5F:6YE9"`D;6]D93L*<F5N
M86UE*"1T96UP;F%M92P@)&9U;&QN86UE*2!O<B!U;FQI;FLH)'1E;7!N86UE
M*3L*?0IR971U<FX@)&9U;&QN86UE.PI]"G-U8B!?<V5T7W!R;V=N86UE('L*
M:68@*&1E9FEN960@)$5.5GM005)?4%)/1TY!345](&%N9"`D14Y6>U!!4E]0
M4D]'3D%-17T@/7X@+R@N*RDO*2!["B1P<F]G;F%M92`]("0Q.PI]"B1P<F]G
M;F%M92!\?#T@)#`["FEF("@D14Y6>U!!4E]414U0?2!A;F0@:6YD97@H)'!R
M;V=N86UE+"`D14Y6>U!!4E]414U0?2D@/CT@,"D@>PHD<')O9VYA;64@/2!S
M=6)S='(H)'!R;V=N86UE+"!R:6YD97@H)'!R;V=N86UE+"`D<WES>U]D96QI
M;7TI("L@,2D["GT*:68@*"$D14Y6>U!!4E]04D]'3D%-17T@;W(@:6YD97@H
M)'!R;V=N86UE+"`D<WES>U]D96QI;7TI(#X](#`I('L*:68@*&]P96X@;7D@
M)&9H+"`G/"<L("1P<F]G;F%M92D@>PIR971U<FX@:68@+7,@)&9H.PI]"FEF
M("@M<R`B)'!R;V=N86UE)'-Y<WM?97AE?2(I('L*)'!R;V=N86UE("X]("1S
M>7-[7V5X97T["G)E='5R;CL*?0I]"F9O<F5A8V@@;7D@)&1I<B`H<W!L:70@
M+UQ1)'-Y<WMP871H7W-E<'U<12\L("1%3E9[4$%42'TI('L*;F5X="!I9B!E
M>&ES=',@)$5.5GM005)?5$5-4'T@86YD("1D:7(@97$@)$5.5GM005)?5$5-
M4'T["B1D:7(@/7X@<R]<421S>7-[7V1E;&EM?5Q%)"\O.PHH*"1P<F]G;F%M
M92`]("(D9&ER)'-Y<WM?9&5L:6U])'!R;V=N86UE)'-Y<WM?97AE?2(I+"!L
M87-T*0II9B`M<R`B)&1I<B1S>7-[7V1E;&EM?21P<F]G;F%M921S>7-[7V5X
M97TB.PHH*"1P<F]G;F%M92`]("(D9&ER)'-Y<WM?9&5L:6U])'!R;V=N86UE
M(BDL(&QA<W0I"FEF("US("(D9&ER)'-Y<WM?9&5L:6U])'!R;V=N86UE(CL*
M?0I]"G-U8B!?9FEX7W!R;V=N86UE('L*)#`@/2`D<')O9VYA;64@?'P]("1%
M3E9[4$%27U!23T=.04U%?3L*:68@*&EN9&5X*"1P<F]G;F%M92P@)'-Y<WM?
M9&5L:6U]*2`\(#`I('L*)'!R;V=N86UE(#T@(BXD<WES>U]D96QI;7TD<')O
M9VYA;64B.PI]"FUY("1P=V0@/2`H9&5F:6YE9"`F0W=D.CIG971C=V0I(#\@
M0W=D.CIG971C=V0H*0HZ("@H9&5F:6YE9"`F5VEN,S(Z.D=E=$-W9"D@/R!7
M:6XS,CHZ1V5T0W=D*"D@.B!@<'=D8"D["F-H;VUP*"1P=V0I.PHD<')O9VYA
M;64@/7X@<R]>*#\]7"Y<+C]<421S>7-[7V1E;&EM?5Q%*2\D<'=D)'-Y<WM?
M9&5L:6U]+SL*)$5.5GM005)?4%)/1TY!345](#T@)'!R;V=N86UE.PI]"G-U
M8B!?<&%R7VEN:71?96YV('L*:68@*"`D14Y6>U!!4E])3DE424%,25I%1'TK
M*R`]/2`Q("D@>PIR971U<FX["GT@96QS92!["B1%3E9[4$%27TE.251)04Q)
M6D5$?2`](#(["GT*9F]R("AQ=R@@4U!!5TY%1"!414U0($-,14%.($1%0E5'
M($-!0TA%(%!23T=.04U%("D@*2!["F1E;&5T92`D14Y6>R)005)?)%\B?3L*
M?0IF;W(@*'%W+R!435!$25(@5$5-4"!#3$5!3B!$14)51R`O*2!["B1%3E9[
M(E!!4E\D7R)](#T@)$5.5GLB4$%27T=,3T)!3%\D7R)](&EF(&5X:7-T<R`D
M14Y6>R)005)?1TQ/0D%,7R1?(GT["GT*:68@*"1%3E9[4$%27U1%35!]*2![
M"F1E;&5T92`D14Y6>U!!4E]#3$5!3GT["GT*?0IS=6(@;W5T<R!["G)E='5R
M;B!I9B`D<75I970["FEF("@D;&]G9F@I('L*<')I;G0@)&QO9V9H(")`7UQN
M(CL*?0IE;'-E('L*<')I;G0@(D!?7&XB.PI]"GT*<W5B(&EN:71?:6YC('L*
M<F5Q=6ER92!#;VYF:6<["G!U<V@@0$E.0RP@9W)E<"!D969I;F5D+"!M87`@
M)$-O;F9I9SHZ0V]N9FEG>R1??2P@<7<H"F%R8VAL:6)E>'`@<')I=FQI8F5X
M<"!S:71E87)C:&5X<"!S:71E;&EB97AP"G9E;F1O<F%R8VAE>'`@=F5N9&]R
M;&EB97AP"BD["GT*<&%C:V%G92!M86EN.PIR97%U:7)E(%!!4CL*=6YS:&EF
M="!`24Y#+"!<)E!!4CHZ9FEN9%]P87(["E!!4BT^:6UP;W)T*$!P87)?87)G
M<RD["F1I92!Q<5MP87(N<&PZ($-A;B=T(&]P96X@<&5R;"!S8W)I<'0@(B1P
M<F]G;F%M92(Z($YO('-U8V@@9FEL92!O<B!D:7)E8W1O<GE<;ET*=6YL97-S
M("UE("1P<F]G;F%M93L*9&\@)'!R;V=N86UE.PI#3U)%.CIE>&ET*"0Q*2!I
M9B`H)$`@/7XO7E]42U]%6$E47UPH*%QD*RE<*2\I.PID:64@)$`@:68@)$`[
M"GT["B0Z.E]?15)23U(@/2`D0"!I9B`D0#L*?0I#3U)%.CIE>&ET*"0Q*2!I
M9B`H)#HZ7U]%4E)/4B`]?B]>7U1+7T58251?7"@H7&0K*5PI+RD["F1I92`D
M.CI?7T524D]2(&EF("0Z.E]?15)23U(["C$["E]?14Y$7U\*````````0T%#
M2$4``'!E<FQX<VDN8P```````````````````/____\`````_____P`````!
M(T5G`````(FKS>\`````_MRZF`````!V5#(0`````/#ATL,`````````````
M```!&P,[Y````!L```#`?O__#`8``/"`__\``0``\('__Q@!``!@F/__:`$`
M`#"9__^T`0``P)G__]@!``#@FO__&`(``&"<__]4`@``P)S__W`"``"@G?__
ML`(``/"?___\`@``(*#__Q`#````H?__1`,``!"A__]8`P``0*/__[P#``!P
MH___V`,``,"D__\4!```T*G__V`$``!`JO__?`0``'"J__^4!```@*O___`$
M``"0LO__H`4``-"T___4!0``L+7__S@&````MO__4`8``+"W__^<!@```+K_
M_^`&````````%``````````!>E(``7@0`1L,!PB0`0``%````!P```#H?___
M)@````!$!Q``````3````#0```#0@/__:Q8```!"#A"/`DD.&(X#0@X@C01"
M#BB,!4$.,(8&00XX@P='#M`%`T(6"@XX00XP00XH0@X@0@X80@X00@X(00L`
M``!(````A````/"6___,`````$(.$(\"0@X8C@-"#B"-!$(.*(P%00XPA@9!
M#CB#!T0.0`)M"@XX1`XP00XH0@X@0@X80@X00@X(2`L`(````-````!TE___
MA`````!!#A"#`DH.L`$"<0H.$$$."$$+/````/0```#@E___$P$```!"#A",
M`D$.&(8#00X@@P1(#`N@@`11#0=$#K"`!`+`"@X@00X800X00@X(2PL``#@`
M```T`0``P)C__WT!````0@X0C0)"#AB,`T$.((8$00XH@P5'#M`!?@H.*$$.
M($$.&$(.$$(."$<+`!@```!P`0``!)K__U$`````10X0@P("1@X(```\````
MC`$``$B:___;`````$(.$(T"0@X8C`-!#B"&!$$.*(,%1PZH($D.P"`">`H.
M*$$.($$.&$(.$$(."$0+2````,P!``#HFO__0@(```!"#A"/`D(.&(X#0@X@
MC01"#BB,!4$.,(8&1`XX@P='#F`#'0$*#CA!#C!!#BA"#B!"#AA"#A!"#@A%
M"Q`````8`@``[)S__RH`````````,````"P"```(G?__V`````!%#A"&`D$.
M&(,#1PZ8($P.F$!)#L!``J8*#AA$#A!!#@A!"Q````!@`@``M)W__PH`````
M````8````'0"``"PG?__)0(```!&#A"/`D(.&(X#0@X@C01"#BB,!4$.,(8&
M00XX@P='#K@@3`[P(0)R"@XX00XP00XH0@X@0@X80@X00@X(0PL"NP[X(4\.
M@")<#O@A00[P(0```!@```#8`@``?)___R@`````10X0@P)=#@@````X````
M]`(``)"?__]"`0```$4.$(8"00X8@P-'#I@@20ZP(`+F"@X800X000X(0@M:
M"@X82`X000X(30M(````,`,``*2@__\%!0```$8.$(\"0@X8C@-"#B"-!$(.
M*(P%00XPA@9(#CB#!T0.4`.F!`H..$T.,$$.*$(.($(.&$(.$$(."$4+&```
M`'P#``!HI?__:@````!(#B`"4`H."$@+`!0```"8`P``O*7__R,`````2`X0
M6@X(`%@```"P`P``U*7__Q`!````1@X0C0)"#AB,`T@.((8$1PXH@P5$#D`"
M0@H.*$8.($$.&$(.$$(."$@+90H.*$$.($$.&$(.$$(."$4+9`Y(20Y09`Y(
M00Y`````K`````P$``"(IO__`P<```!&#A"/`E`.&(X#40X@C01)#BB,!4$.
M,(8&00XX@P='#O`"`_$!#O@"80Z``V$.^`)"#O`"`GL*#CA$#C!!#BA"#B!"
M#AA"#A!"#@A*"P-&`0[X`DL.@`-?#O@"00[P`E\.^`)$#H`#4`Z(`TL.D`-,
M#O`"`O0*#CA$#C!!#BA"#B!"#AA"#A!"#@A&"P+C#O@"2@Z``T<.^`)!#O`"
M```P````O`0``.BL__\S`@```$8.$(P"2`X8A@-!#B"#!$0.,`-Y`0H.($$.
M&$$.$$(."$@+-````/`$``#TKO__W0````!%#A"&`D0.&(,#1`XP`H<*#AA!
M#A!!#@A*"VT*#AA$#A!!#@A%"P`H````*`4``*QX__\B`@```$4.$(8"00X8
M@P-$#E`#=P$*#AA##A!!#@A!"Q0```!4!0``<*___TH`````2`X0`D$."$@`
M``!L!0``J*___Z<!````1@X0CP)%#AB.`T4.((T$0@XHC`5$#C"&!D4..(,'
M1PY``N$*#CA!#C!!#BA"#B!"#AA"#A!"#@A#"P!`````N`4```RQ__]+`@``
M`$8.$(X"1@X8C0-"#B",!$$.*(8%1`XP@P8#FP$*#BA!#B!"#AA"#A!"#@A+
M"P```````!````#\!0``&+/__Q$`````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````$`C````````\"(````````!````````
M`,T"`````````0````````#8`@````````\`````````600````````,````
M```````@````````#0````````!T6P```````!D``````````+P````````;
M``````````@`````````&@`````````(O````````!P`````````"```````
M``#U_O]O`````-`#````````!0````````"P#0````````8`````````$`4`
M```````*`````````'P$````````"P`````````8`````````!4`````````
M```````````'`````````&@3````````"`````````!X!@````````D`````
M````&``````````8````````````````````^___;P`````!```(`````/[_
M_V\`````Z!(```````#___]O``````$`````````\/__;P`````L$@``````
M`/G__V\`````!```````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````!"\````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````C`````````"E!!4BYP;0H``````````-AB
M````````1T-#.B`H1TY5*2`Q,BXR+C```"YS:'-T<G1A8@`N:6YT97)P`"YN
M;W1E+F=N=2YP<F]P97)T>0`N;F]T92YG;G4N8G5I;&0M:60`+FYO=&4N04))
M+71A9P`N9VYU+FAA<V@`+F1Y;G-Y;0`N9'EN<W1R`"YG;G4N=F5R<VEO;@`N
M9VYU+G9E<G-I;VY?<@`N<F5L82YD>6X`+FEN:70`+G1E>'0`+F9I;FD`+G)O
M9&%T80`N96A?9G)A;65?:&1R`"YE:%]F<F%M90`N:6YI=%]A<G)A>0`N9FEN
M:5]A<G)A>0`N9'EN86UI8P`N9V]T`"YD871A`"YB<W,`+F-O;6UE;G0`````
M````````````````````````````````````````````````````````````
M``````````````````````````L````!`````@`````````8`P```````!@#
M````````'`````````````````````$````````````````````3````!P``
M``(`````````.`,````````X`P```````%`````````````````````(````
M````````````````)@````<````"`````````(@#````````B`,````````D
M````````````````````!````````````````````#D````'`````@``````
M``"L`P```````*P#````````(`````````````````````0`````````````
M``````!'````]O__;P(`````````T`,```````#0`P```````$`!````````
M!@`````````(````````````````````40````L````"`````````!`%````
M````$`4```````"@"`````````<````!````"``````````8`````````%D`
M```#`````@````````"P#0```````+`-````````?`0`````````````````
M``$```````````````````!A````____;P(`````````+!(````````L$@``
M`````+@`````````!@`````````"``````````(`````````;@```/[__V\"
M`````````.@2````````Z!(```````"```````````<````!````"```````
M`````````````'T````$`````@````````!H$P```````&@3````````>`8`
M```````&``````````@`````````&`````````"'`````0````8`````````
M`"``````````(````````!L````````````````````$````````````````
M````C0````$````&`````````"`@````````("````````!1.P``````````
M````````$````````````````````),````!````!@````````!T6P``````
M`'1;````````#0````````````````````0```````````````````"9````
M`0````(``````````&``````````8````````&!!```````````````````0
M````````````````````H0````$````"`````````&"A````````8*$`````
M``#D````````````````````!````````````````````*\````!`````@``
M``````!(H@```````$BB````````$`8```````````````````@`````````
M``````````"Y````#@````,``````````+P`````````K`````````@`````
M```````````````(``````````@`````````Q0````\````#``````````B\
M````````"*P````````(````````````````````"``````````(````````
M`-$````&`````P`````````0O````````!"L````````T`$````````'````
M``````@`````````$`````````#:`````0````,`````````X+T```````#@
MK0```````"`"```````````````````(``````````@`````````WP````$`
M```#``````````#``````````+`````````H````````````````````"```
M`````````````````.4````(`````P`````````HP````````"BP````````
M*`````````````````````@```````````````````#J`````0```#``````
M```````````````HL````````!(````````````````````!``````````$`
M`````````0````,`````````````````````````.K````````#S````````
9`````````````0``````````````````````
